****************************** SETTINGS AND DATA *******************************

version 16.1

clear all
log close _all
set more off
set emptycells drop
set varabbrev off

local directory = ""
local folder = "`directory'" + "Replication/Data"
cd "`folder'"

log using ../Output/Voting_Peer_Effects.log, replace name("Voting Peer Effects")

* Justice Vote Data
use SCDB_Votes.dta

* Segal-Cover scores for justices
merge m:1 justice using SegalCover.dta, keep(master match) nogenerate

* Justice Characteristic Data
append using justicesdata.dta, keep(spaethid success id)
* Earliest successful nomination
drop if success == 0 & !missing(spaethid) // Drop unsuccessful nominations (spaethid == . is the nominations data)
bysort spaethid: egen min_id = min(id)
drop if id != min_id & !missing(spaethid)  // Drop non-first success
* Create common id variable to match upon
replace justice = spaethid if !missing(spaethid) // Common identifier between justices data and SCDB
bysort justice: egen id_match = min(id) // Match id (unique identifier in justices data) to SCDB
replace id = id_match if missing(id)  // Rename to same name as in justices data
drop if missing(justiceName) // Drop justices data points
drop min_id id_match

* US Court of Appeals History / Experience, Party of Appointing President, for justices
merge m:1 id using justicesdata.dta, keep(master match) keepusing(name dateserb fedca fedcayr1 fedcayr2 prespart prdssr) nogenerate
drop spaethid id

* Set  Working Directory for Output
cd "../Output"

**************************** INTRODUCTORY ANALYSIS *****************************

* Vote direction totals (including recusions and unclear directions)
tab direction, missing

* Generate vote direction as binary (0/1) variable
gen vote_direction = 1 if direction == 1 // Conservative vote
replace vote_direction = 0 if direction == 2 // Liberal vote 
tab vote_direction, missing

label variable vote_direction "Vote Direction"
label define vote_direction_label 0 "Liberal" 1 "Conservative", replace
label values vote_direction vote_direction_label

* Adjustment of Equally Divided Court Votes
replace vote_direction = 0.5 if minVotes == majVotes & missing(direction) & (lcDispositionDirection != 3 | decisionDirection != 3) & !missing(vote) 
// To resolve direction, is sufficient that lcDispositionDirection or decisionDirection is specified. 
// If neither is, exclude as unspecifiable ideological direction. 
// Only want to replace vote for the justice who is not missing

* VoteID is structured into 6 components:  Year - case number - docket number 
* in case - case issue in docket - group vote - justice vote. 
* Case effects are thus unique sets of first 5 components
gen casevoteId_s = substr(voteId, 1, 17) // String
encode casevoteId_s, gen(casevote)
drop casevoteId_s

* Justice active in (directional) case
gen active = !missing(vote_direction)
* Any justice active in case (Cases with defined ideological direction)
bysort casevote: egen directional = max(active) // Since absent justice doesn't vote, don't need to exclude self

* Dummies for justice
tab justice

* Dummies for referring court - US Courts of Appeal (Circuit Courts)
// Want the 11 numbered circuits, DC circuit, and United States Court of Appeals for the Federal Circuit
tab caseSource
tab caseSource, nolabel // To see labels for the circuit courts of appeal
* i(8 21(1)32).caseSource 
// Case source 8, 21-32 are circuit courts of appeal

* Dummies for issue area
tab issueArea
tab issueArea vote_direction, missing

* Dummies for lower court disposition direction
tab lcDispositionDirection, missing
// Recode missing as unspecified (3)
// Original 0s have no decision direction so dropped anyway
replace lcDispositionDirection = 3 if lcDispositionDirection == 0
replace lcDispositionDirection = 3 if missing(lcDispositionDirection)

label define lcDispositionDirection_label 1 "Conservative" 2 "Liberal" 3 "Unspecifiable", replace
label values lcDispositionDirection lcDispositionDirection_label

* Judge prior history on US Circuit Courts of Appeal
// Only consider home effect when lc decision has direction (lib / conservative 
// - unspecified sample far too small, also unclear what home bias would involve for unspecified)
replace fedca = 0 if fedca == 888 // No service on Circuit Courts of Appeal
gen homeCircuitCourt = (fedca == caseSource - 20) & lcDispositionDirection != 3 // Matches 1-12 in fedca with 21-32 in caseSource

gen fedcaYears = fedcayr2 - fedcayr1
gen homeCircuitCourtYears = homeCircuitCourt * fedcaYears // Number of years on the circuit court, case from court

label variable homeCircuitCourt "Justice Home Court"
label define homeCircuitCourt_label 0 "Away (or Unspecified LC)" 1 "Home", replace
label values homeCircuitCourt homeCircuitCourt_label

label variable homeCircuitCourtYears "Justice Home Court Tenure"


* Start Date for Justice Supreme Court Tenure (Oath Date) 
gen oathdate = date(dateserb, "MDY") 
label variable oathdate "date of judicial oath"
format oathdate %td

* Justice Tenure
* Years since first term (inclusive)
bysort justice (voteId): gen tenure = term - term[1] + 1 // Uses first case as first term, start tenure is 1
* Term Justice Began Service (Took Oath)
bysort justice (voteId): gen term_start = year(oathdate) - (month(oathdate) <= 7) // Up to July is part of prior year term 
bysort justice (voteId): replace tenure = term - term_start + 1 if term_start < term[1] & term[1] == 1946
// Use oath date as first term year for justices serving on court at period start, start tenure is 1
drop term_start oathdate

* Invidual vote to overturn lower court decision
gen overturnLC = (lcDispositionDirection != direction) if !missing(direction) & lcDispositionDirection != 3
// Excluding non votes and non-directional LC votes are important, otherwise gives spurious first year reticence.
replace overturnLC = 0.5 if vote_direction == 0.5 & lcDispositionDirection != 3 
// Equally divided cases, with directional LC vote (equally divided cases already restricted to either directional vote or LC vote) 

* Supreme Court verdict to overturn lower court decision
gen overturnLC_verdict = (lcDispositionDirection != decisionDirection) if !missing(decisionDirection) & lcDispositionDirection != 3
// Excluding non-directional cases and non-directional LC votes (but includes absent justices in directional cases). I.e. variable defined by case 

* Regressions begin to inadvertently drop observations with missing caseSource 
* or missing issueArea etc (with the effect of dropping all Interstate Relations
* data with 1/0 vote direction); to prevent this recode 'missing' category.
replace issueArea = 0 if missing(issueArea) 
replace caseSource = 0 if missing(caseSource) 


*** Labels

* label dir
* label list varIssuesAreas varCaseSources fedca // issueArea, caseSource, fedca labels have these names
label define varIssuesAreas 0 "Unknown", add
label values issueArea varIssuesAreas
label define varCaseSources 0 "Unknown", add
label values caseSource varCaseSources
label define fedca 0 " nominee did not serve as u.s. circuit ct judge", add
label values fedca fedca
label define prespart 1 "Democratic" 6 "Republican", replace
*label define varUSDirection 0 "Not Party" 1 "Conservative" 2 "Liberal", add
*label values petitionerUSDirection respondentUSDirection  varUSDirection

* label define varDecisionDirection 0 "Unknown", add
* label values lcDispositionDirection varDecisionDirection

*** Graphing Conventions

* Issue Area
* Do not want to display issue areas with minimal number of decisions (with vote direction)
gen issueArea_major = (issueArea != 0 & issueArea != 11 & issueArea != 13 & issueArea != 14)

* Graph Numbering
local graphnumber = 1


*************************** DESCRIPTIVE STATISTICS *****************************

*** Descriptive Statistics & Table 1
* Total Number of Votes
count
count if !missing(vote_direction) // Directional votes

* Total Number of Cases
preserve
bysort caseId (vote_direction): keep if _n == 1
count
count if !missing(vote_direction) // Cases with at least one directional vote
restore

* Total Number of Case-Issue Pairs
preserve
bysort casevote (vote_direction): keep if _n == 1
count
count if !missing(vote_direction) // Cases with at least one directional vote
restore

* Number of Cases by Number of Active (Voting) Justices
preserve
keep if !missing(vote_direction) 
bysort casevote: gen active_justices = _N
bysort casevote: keep if _n == 1
bysort caseId (active_justices): keep if _n == 1
tab active_justices
restore

* Distribution of Vote Ideology
tab vote_direction

* Distribution of Lower Court Decision Direction
tab lcDispositionDirection if !missing(vote_direction)
tab lcDispositionDirection if !missing(vote_direction) & lcDispositionDirection != 3 // Only cases with directional LC

* Distribution of Overturn Propensity
tab overturnLC // Vote to overturn
tab overturnLC_verdict  // SC verdict to overturn
//Endogenous review (majority of decisions overturned)

* Distribution of Vote Ideology by Issue Area, Circuit Court of Appeal, Term, Justice
tab issueArea vote_direction if issueArea_major == 1, row nofreq
tab caseSource vote_direction if caseSource == 8 | (caseSource >= 21 & caseSource <= 32), row nofreq
tab term vote_direction, row nofreq
tab justice vote_direction, row nofreq


** Table 1 (Summarises above information)
preserve

gen votes = 1 // For number of votes
label variable votes "Directional Votes"
label define votes_label 1 "Total", replace
label values votes votes_label

* Temporary Variable Titles
label variable issueArea "Legal Issue Area"
label variable caseSource "Circuit Court"

bysort casevote (vote_direction): gen provision = 1 if _n == 1 // For number of case-provision pairs (any directional vote in case)

* Lower Court Directional Vote (for Supreme Court Directional Votes)
gen lcVoteDirection = (lcDispositionDirection == 1) if lcDispositionDirection != 3 & !missing(vote_direction) 

replace lcVoteDirection = 100 * lcVoteDirection // Percentage terms
replace vote_direction = 100 * vote_direction // Percentage terms
replace overturnLC = 100 * overturnLC // Percentage terms

* Temporary Simplification of Categories (Limit to those desired for tables)
replace caseSource = . if (caseSource == 8 | (caseSource >= 21 & caseSource <= 32)) == 0 // Circuit Courts of Appeal
replace issueArea = . if issueArea_major == 0 // Issue Area (major)

tabout votes issueArea caseSource if !missing(vote_direction) using Tables/table1.tex, ///
	cells(sum votes sum provision mean vote_direction mean lcVoteDirection mean overturnLC) ///
	format(0c 0c 2 2 2) sum oneway style(tex) h2( & \textbf{Votes} & \textbf{Cases} & \textbf{Vote Direction} & \textbf{Lower Court} & \textbf{Overturn} \\) h3(&&& \textit{(Cons. \%)} & \textit{(Cons. \%)} & \textit{(\%)} \\) ptotal(none) body replace

restore


*** Other Descriptive Statistics

* Mean Vote Direction over time
preserve
collapse (mean) vote_direction, by(term)
line vote_direction term
restore

graph save Graphs/fig`graphnumber'.gph, replace
local graphnumber = `graphnumber' + 1


** Endogenous Case Selection
// Does the composition of cases change with the ideology of justices - consider
// composition of decision direction in lower court of cases reviewed 

* Composition of LC Decision Direction of SC cases, Mean Segal-Cover, by Natural Court
preserve
* Mean Segal-Cover score of justices (not leave out mean)
bysort casevote (voteId): egen scIdeology_ave = mean(scIdeology)  
* Cases with Directional decisions in lower court
bysort casevote: keep if _n == 1
keep if lcDispositionDirection != 3
gen lcLiberalShare = (lcDispositionDirection == 2) // Dummy for liberal LC decision, otherwise conservative
* Sample size for natural court
bysort naturalCourt: gen naturalCourtSample = _N
* Mean liberal LC decision share, mean Segal-Cover score, by Natural Court
collapse (mean) lcLiberalShare scIdeology_ave naturalCourtSample, by(naturalCourt)
scatter lcLiberalShare scIdeology_ave [w=naturalCourtSample], msymbol(circle_hollow)
restore

graph save Graphs/fig`graphnumber'.gph, replace
local graphnumber = `graphnumber' + 1


** Home Court Bias

* Home Court Bias by Justice
* First look at percentage of lower court decisions justices vote to overturn
preserve
* Directional votes in both lower and Supreme Court
keep if lcDispositionDirection != 3 & !missing(vote_direction) 
* Justices with Appelate Court heritage
bysort justice: keep if fedca != 0
* Vote to Overturn Lower Court Decision
gen vote_overturn = overturnLC // To deal properly with equally divided court cases
* Number of Home Case Votes by Justice with Overturn Opportunity (i.e. ~ Justice sample size)
bysort justice homeCircuitCourt: gen justice_votes = _N
// Weighting by number of home/away votes

collapse (mean) vote_overturn fedcaYears justice_votes, by(justice homeCircuitCourt)
bysort justice (homeCircuitCourt): gen vote_overturn_home_bias = vote_overturn[1] - vote_overturn[2] 
scatter vote_overturn_home_bias fedcaYears [w=justice_votes] if homeCircuitCourt == 1, msymbol(circle_hollow)

restore

graph save Graphs/fig`graphnumber'.gph, replace
local graphnumber = `graphnumber' + 1


**************** JUSTICE IDEOLOGY EFFECTS RECURSIVE ESTIMATION ****************


** Justice Active / Absentee Status

* Justice active in case
*gen active = (!missing(vote_direction))
* Number of active justices in case
bysort casevote (voteId): egen number_active = total(active == 1)
* Number of absent judges in case (only captures recused, not death/retirement)
bysort casevote (voteId): egen number_absent = total(active == 0) // Probably only captures recused, not death/retirement
* Absent judge in case
bysort casevote: gen absent_justice_case = (number_absent>0)
label var absent_justice_case "Justice Absent in Case"

* Frequency and Scale of Absences
tab number_absent if !missing(vote_direction)
tab number_absent if directional == 1


** Defined Ideology and Absence of Justice with Defined Ideology
// When counting all justices ideology, only want to average over justices with defined ideology
// When counting active justice ideology, non-issue - any active justice has defined ideology
// When counting absent justice ideology, only want to average over justices with defined ideology
// Only include indicator for absent justice if justice with defined ideology is absent

* Justices with defined ideology measure
bysort justice: egen ever_ideology_justice = max(active) 
bysort casevote: egen number_absent_ideology_j = total(active == 0 & ever_ideology_justice == 1)
bysort casevote: gen absent_justice_case_j_temp = (number_absent_ideology_j > 0)

* Justices by issue area pairs with defined ideology measure
bysort justice issueArea: egen ever_ideology_justice_issue = max(active) 
bysort casevote: egen number_absent_ideology_j_ia = total(active == 0 & ever_ideology_justice_issue == 1)
bysort casevote: gen absent_justice_case_j_ia_temp = (number_absent_ideology_j_ia > 0)

* Justices by natural court by issue area pairs with defined ideology measure
bysort justice issueArea naturalCourt: egen ever_ideology_justice_issue_nc = max(active) 
// Even when counting all, only want to average over justices with defined ideology
bysort casevote: egen number_absent_ideology_j_ia_nc = total(active == 0 & ever_ideology_justice_issue_nc == 1)
bysort casevote: gen absent_justice_case_j_ia_nc_temp = (number_absent_ideology_j_ia_nc > 0)


*** 1. Iterative Estimation of Models

* Set default omitted dummy variable to none, since estimating without constant
fvset base none justice caseSource
fvset base first issueArea term naturalCourt
fvset base 3 lcDispositionDirection 

* Save Data for Robustness Tests
save ../Data/robustnessData.dta, replace


** 1a. Model 1 - Justice fixed effects, term fixed effects, clustered by case

local specificationlist `" "all" "joint" "active" "'

foreach spec in `specificationlist' {

capture drop justice_all_mean_1a justice_active_mean_1a justice_absent_mean_1a justice_FE_1a_prior
capture drop absent_justice_case_j

* Initialise Peer Variables 
// Constant will be dropped
gen justice_all_mean_1a = 0
gen justice_active_mean_1a = 0
gen justice_absent_mean_1a = 0
gen justice_FE_1a_prior = .

gen absent_justice_case_j = 0

local step_size = .

while `step_size' > 0.1^6 {

** Estimate regression - Judge fixed effects, dummies for term, clustered by case

* Peer effects, all other justices
if "`spec'" == "all" {
qui reg vote_direction i.justice justice_all_mean_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
est store a_all
}
* Peer effects, active justices only
if "`spec'" == "active" {
qui reg vote_direction i.justice justice_active_mean_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
est store a_active
}
* Peer effects, active and absent justices
if "`spec'" == "joint" {
qui reg vote_direction i.justice justice_active_mean_1a justice_absent_mean_1a absent_justice_case_j i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
est store a_joint
}

est table a_`spec', stats(r2 N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel

estimates restore a_`spec'
	
matrix all_ols_coef = e(b)
matrix justice_ols_coef_1a = all_ols_coef[1,1..36]' // 36 justices by issue area pairs in sample
matrix colnames justice_ols_coef_1a = justice_FE_1a
* matrix list justice_ols_coef_1a

drop justice_all_mean_1a justice_active_mean_1a justice_absent_mean_1a justice_active_mean_1a


** Extract Justice Fixed Effects - a
// Using justice fixed effects, term dummies

** Matching justice with coefficient
* Note that matrices are not cleared with preserve / restore
preserve
bysort justice (dateDecision): keep if _n == 1 // Justices already ordered, earliest obs for each justice
mkmat justice, matrix(justice_list)
restore

matrix justice_ols_coef_merge_1a = (justice_list,justice_ols_coef_1a)
* matrix list justice_ols_coef_merge_1a

matsave justice_ols_coef_merge_1a, replace saving path("Estimates/")

** Merge coefficient as variable into dataset
merge m:1 justice using Estimates/justice_ols_coef_merge_1a.dta, keepusing(justice_FE_1a) keep(master match) nogenerate
label variable justice_FE_1a "Model 1 Ideology Estimates" 

sort voteId

* Normalise Justice FE to Baseline Mean (i.e. without Peer Effects)
// Note that adding/subtracting a constant is fully accounted for by the justice
// FE in following estimation, no effect on peer effects estimate

qui summarize justice_FE_1a_prior
local mean_prior = r(mean)
qui summarize justice_FE_1a
local mean_new = r(mean)

replace justice_FE_1a = justice_FE_1a - (`mean_new' - `mean_prior') if !missing(justice_FE_1a_prior)


** Peer Variable Creation - a

* Mean of coefficient for all other justices
bysort casevote ever_ideology_justice (voteId): egen justice_all_sum = total(justice_FE_1a)
bysort casevote ever_ideology_justice (voteId): gen justice_all_mean_1a = (justice_all_sum - justice_FE_1a) / (_N - 1)
drop justice_all_sum

* Mean of coefficients for other active justices
bysort casevote active (voteId): egen justice_active_sum = total(justice_FE_1a)
bysort casevote active (voteId): gen justice_active_mean_1a = (justice_active_sum - justice_FE_1a) / (_N - 1)
drop justice_active_sum

* Mean of coefficients for absent justices
bysort ever_ideology_justice: egen ideology_defined_mean_a = mean(justice_FE_1a)
bysort casevote ever_ideology_justice (voteId): egen justice_absent_sum = total(justice_FE_1a * (1-active))
// Mean of absent justices (don't need leave out mean, since absent justices omitted anyway)
gen justice_absent_mean_1a = justice_absent_sum / number_absent_ideology_j - ideology_defined_mean_a
// Subtracting mean defined ideology to provide natural zero for absent ideology
replace justice_absent_mean_1a = 0 if number_absent_ideology_j == 0 // No absent judges with defined ideology
drop justice_absent_sum ideology_defined_mean_a

label variable justice_all_mean_1a "Mean All Peer Justices"
label variable justice_active_mean_1a "Mean Active Peer Justices"
label variable justice_absent_mean_1a "Mean Absent Peer Justices"


** Measure of change in justice ideology measure
gen justice_FE_change = justice_FE_1a - justice_FE_1a_prior
summarize justice_FE_change
local step_size = r(sd)
disp `step_size'
drop justice_FE_change

replace justice_FE_1a_prior = justice_FE_1a
replace absent_justice_case_j = absent_justice_case_j_temp // Initialise for iterations with peer variable

drop justice_FE_1a

}

}

est table a_all a_active a_joint, ///
	stats(r2 N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel

esttab a_all a_active a_joint using Tables/table4a.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
	noomitted nobaselevels keep(justice_all_mean_1a justice_active_mean_1a justice_absent_mean_1a) stats(r2 N, fmt(%9.4f %9.0g) labels(R-squared Observations)) legend label ///
	style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Ideology Results - Justice Vote Direction (Conservative $\%$)") replace


*** 1b. Model 2 - Justice by issue area fixed effects, term by issue area fixed effects, clustered by case

local specificationlist `" "all" "joint" "active" "'

foreach spec in `specificationlist' {

capture drop justice_all_mean_1b justice_active_mean_1b justice_absent_mean_1b justice_FE_1b_prior
capture drop absent_justice_case_j_ia

* Initialise Peer Variables 
// Constant will be dropped
gen justice_all_mean_1b = 0
gen justice_active_mean_1b = 0
gen justice_absent_mean_1b = 0
gen justice_FE_1b_prior = .

gen absent_justice_case_j_ia = 0

local step_size = .

while `step_size' > 0.1^6 {

** Estimate Regression - Judge by issue area fixed effects, issue area by term FE for differential time trends, clustered by case
* Peer effects, all other justices
if "`spec'" == "all" {
qui reg vote_direction i.justice#i.issueArea justice_all_mean_1b i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.issueArea#i.term, noconstant vce(cluster caseId)
est store b_all
}
* Peer effects, active justices only
if "`spec'" == "active" {
qui reg vote_direction i.justice#i.issueArea justice_active_mean_1b i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.issueArea#i.term, noconstant vce(cluster caseId)
est store b_active
}
* Peer effects, active and absent justices
if "`spec'" == "joint" {
qui reg vote_direction i.justice#i.issueArea justice_active_mean_1b justice_absent_mean_1b absent_justice_case_j_ia i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.issueArea#i.term, noconstant vce(cluster caseId)
est store b_joint
}

est table b_`spec', stats(r2 N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel

estimates restore b_`spec'

matrix all_ols_coef = e(b)
matrix justice_ols_coef_1b = all_ols_coef[1,1..444]' // 444 justices by issue area pairs in sample
matrix colnames justice_ols_coef_1b = justice_FE_1b
*matrix list justice_ols_coef_1b

drop justice_all_mean_1b justice_active_mean_1b justice_absent_mean_1b justice_active_mean_1b


** Extract Justice by Issue Area Fixed Effects
// Using justice by issue area fixed effects, term by issue area fixed effects

** Matching justice and issue with coefficient
* Note that matrices are not cleared with preserve / restore
preserve
keep if vote_direction <= 1 // Only justice - issue area pairs with directional votes
bysort justice issueArea (dateDecision): keep if _n == 1 // Justices already ordered, earliest obs for each justice
tab issueArea // Number of justice-issue area coefficients
mkmat justice issueArea, matrix(justice_issue_list)
restore

matrix justice_ols_coef_merge_1b = (justice_issue_list,justice_ols_coef_1b)
*matrix list justice_ols_coef_merge_1b

matsave justice_ols_coef_merge_1b, replace saving path("Estimates/")

** Merge coefficient as variable into dataset
merge m:1 justice issueArea using Estimates/justice_ols_coef_merge_1b.dta, keepusing(justice_FE_1b) keep(master match) nogenerate
label variable justice_FE_1b "Model 2 Ideology Estimates" 

* Unmerged data occurs where justice does not have any observations with issue 
* area within sample (of 1/0 cases) but has cases of this type in excluded sample. 
* Also obs with missing issue area.

sort voteId

* Normalise Justice FE to Baseline Mean (i.e. without Peer Effects)
// Note that adding/subtracting a constant by issue area is fully accounted for 
// by the justice by issue area FE in following estimation, no effect on peer effects estimate

bysort issueArea: egen justice_mean_new = mean(justice_FE_1b)
bysort issueArea: egen justice_mean_old = mean(justice_FE_1b_prior)

replace justice_FE_1b = justice_FE_1b - (justice_mean_new - justice_mean_old) if !missing(justice_FE_1b_prior)
drop justice_mean_new justice_mean_old


** Peer Variable Creation - b

* Mean of coefficient for all other justices
bysort casevote ever_ideology_justice_issue (voteId): egen justice_all_sum = total(justice_FE_1b)
bysort casevote ever_ideology_justice_issue (voteId): gen justice_all_mean_1b = (justice_all_sum - justice_FE_1b) / (_N - 1)
drop justice_all_sum

* Mean of coefficients for other active justices
bysort casevote active (voteId): egen justice_active_sum = total(justice_FE_1b)
bysort casevote active (voteId): gen justice_active_mean_1b = (justice_active_sum - justice_FE_1b) / (_N - 1)
drop justice_active_sum

* Mean of coefficients for absent justices
bysort ever_ideology_justice_issue issueArea: egen ideology_defined_mean_b = mean(justice_FE_1b)
bysort casevote ever_ideology_justice_issue (voteId): egen justice_absent_sum = total(justice_FE_1b * (1-active))
// Mean of absent justices (don't need leave out mean, since absent justices omitted anyway)
gen justice_absent_mean_1b = justice_absent_sum / number_absent_ideology_j_ia - ideology_defined_mean_b
// Subtracting mean defined ideology to provide natural zero for absent ideology
replace justice_absent_mean_1b = 0 if number_absent_ideology_j_ia == 0 // No absent judges with defined ideology
drop justice_absent_sum ideology_defined_mean_b

label variable justice_all_mean_1b "Mean All Peer Justices"
label variable justice_active_mean_1b "Mean Active Peer Justices"
label variable justice_absent_mean_1b "Mean Absent Peer Justices"


** Measure of change in justice ideology measure
gen justice_FE_change = justice_FE_1b - justice_FE_1b_prior
summarize justice_FE_change
local step_size = r(sd)
disp `step_size'
drop justice_FE_change

replace justice_FE_1b_prior = justice_FE_1b
replace absent_justice_case_j_ia = absent_justice_case_j_ia_temp // Initialise for iterations with peer variable

drop justice_FE_1b

}

}

est table b_all b_active b_joint, ///
	stats(r2 N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel
	
esttab b_all b_active b_joint using Tables/table4b.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
	noomitted nobaselevels keep(justice_all_mean_1b justice_active_mean_1b justice_absent_mean_1b) stats(r2 N, fmt(%9.4f %9.0g) labels(R-squared Observations)) legend label ///
	style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Ideology Results - Justice Vote Direction (Conservative $\%$)") replace

	
*************** FIRST STAGE ESTIMATION USING WITHIN FE ESTIMATOR **************

*** 2. Alternative First Stage Ideology Estimates Using Within FE Estimator
	
** 2a. Model 1 - Judge fixed effect, dummies for circuit court of appeal, year, issue area, lower court decision

xtset justice
local panelvar_j = r(panelvar)
local panelvar_j_name "Justice FE"

local specificationlist `" "all" "joint" "active" "'

foreach spec in `specificationlist' {

capture drop justice_all_mean_within_1a justice_active_mean_within_1a justice_absent_mean_within_1a justice_within_FE_1a_prior
capture drop absent_justice_case_j
	
* Initialise Peer Variables 
// Constant will be dropped
gen justice_all_mean_within_1a = 0
gen justice_active_mean_within_1a = 0
gen justice_absent_mean_within_1a = 0
gen justice_within_FE_1a_prior = .

gen absent_justice_case_j = 0

local step_size = .

while `step_size' > 0.1^6 {

** Peer Effects Regression
* Peer effects, all other justices
if "`spec'" == "all" {
qui xtreg vote_direction justice_all_mean_within_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, fe vce(cluster caseId) nonest dfadj
est store a_within_all
}
* Peer effects, active justices only
if "`spec'" == "active" {
qui xtreg vote_direction justice_active_mean_within_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, fe vce(cluster caseId) nonest dfadj
est store a_within_active
}
* Peer effects, active and absent justices
if "`spec'" == "joint" {
qui xtreg vote_direction justice_active_mean_within_1a justice_absent_mean_within_1a absent_justice_case_j i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, fe vce(cluster caseId) nonest dfadj
est store a_within_joint
}

* Record Panel FE
estadd local absorbed_fe_j =  cond(e(ivar) == "`panelvar_j'","Yes","No",""), replace

* Full R-squared
predict uhat, e
qui summarize uhat
local uvar = r(Var)

qui summarize vote_direction if e(sample) == 1
local yvar = r(Var)

estadd scalar r2_full = 1 - `uvar'/`yvar'
drop uhat

est table a_within_`spec', stats(r2_full N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel


** Extract (Mean Zero) Fixed Effects 
est restore a_within_`spec'
predict justice_within_FE_1a, u
* Ideology Estimates Standard Deviation
qui summarize justice_within_FE_1a
estadd scalar sigma_justice = r(sd)
// Filter predictions down to out of sample cases (i.e. absent)
bysort justice (vote_direction): replace justice_within_FE_1a = justice_within_FE_1a[_n-1] if missing(justice_within_FE_1a)

drop justice_all_mean_within_1a justice_active_mean_within_1a justice_absent_mean_within_1a justice_active_mean_within_1a

* Normalise Justice FE to Baseline Mean (i.e. without Peer Effects)
// Note that adding/subtracting a constant is fully accounted for by the justice 
// FE in following estimation, no effect on peer effects estimate

egen justice_mean_new = mean(justice_within_FE_1a)
egen justice_mean_old = mean(justice_within_FE_1a_prior)

replace justice_within_FE_1a = justice_within_FE_1a - (justice_mean_new - justice_mean_old) if !missing(justice_within_FE_1a_prior)
drop justice_mean_new justice_mean_old


** Peer Variable Creation - a

* Mean of coefficient for all other justices
bysort casevote ever_ideology_justice (voteId): egen justice_all_sum = total(justice_within_FE_1a)
bysort casevote ever_ideology_justice (voteId): gen justice_all_mean_within_1a = (justice_all_sum - justice_within_FE_1a) / (_N - 1)
drop justice_all_sum

* Mean of coefficients for other active justices
bysort casevote active (voteId): egen justice_active_sum = total(justice_within_FE_1a)
bysort casevote active (voteId): gen justice_active_mean_within_1a = (justice_active_sum - justice_within_FE_1a) / (_N - 1)
drop justice_active_sum

* Mean of coefficients for absent justices
bysort ever_ideology_justice: egen ideology_within_defined_mean_a = mean(justice_within_FE_1a)
bysort casevote ever_ideology_justice (voteId): egen justice_absent_sum = total(justice_within_FE_1a * (1-active))
// Mean of absent justices (don't need leave out mean, since absent justices omitted anyway)
gen justice_absent_mean_within_1a = justice_absent_sum / number_absent_ideology_j - ideology_within_defined_mean_a
// Subtracting mean defined ideology to provide natural zero for absent ideology
replace justice_absent_mean_within_1a = 0 if number_absent_ideology_j == 0 // No absent judges with defined ideology
drop justice_absent_sum ideology_within_defined_mean_a

label variable justice_all_mean_within_1a "Mean All Peer Justices"
label variable justice_active_mean_within_1a "Mean Active Peer Justices"
label variable justice_absent_mean_within_1a "Mean Absent Peer Justices"


** Measure of change in justice ideology measure
gen justice_FE_change = justice_within_FE_1a - justice_within_FE_1a_prior
summarize justice_FE_change
local step_size = r(sd)
disp `step_size'
drop justice_FE_change

replace justice_within_FE_1a_prior = justice_within_FE_1a
replace absent_justice_case_j = absent_justice_case_j_temp // Initialise for iterations with peer variable

drop justice_within_FE_1a

}

* Save Final Iteration Results
frame copy default `spec'_a, replace	

}

est table a_within_all a_within_active a_within_joint, ///
	stats(r2_full N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel

esttab a_within_all a_within_active a_within_joint using Tables/table4a_within.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
	noomitted nobaselevels keep(justice_all_mean_within_1a justice_active_mean_within_1a justice_absent_mean_within_1a) stats(r2_full N, fmt(%9.4f %9.0g) labels(R-squared Observations)) legend label ///
	style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Ideology Results - Justice Vote Direction (Conservative $\%$)") replace


** 2b. Model 2 - Judge fixed effect by issue area, dummies for circuit court of appeal, issue area by term fixed effects, lower court decision

egen justiceIssueArea = group(justice issueArea)
xtset justiceIssueArea
local panelvar_jia = r(panelvar)
local panelvar_jia_name "Justice x Issue Area FE"

local specificationlist `" "all" "joint" "active" "'

foreach spec in `specificationlist' {

capture drop justice_all_mean_within_1b justice_active_mean_within_1b justice_absent_mean_within_1b justice_within_FE_1b_prior
capture drop absent_justice_case_j_ia

* Initialise Peer Variables 
// Constant will be dropped
gen justice_all_mean_within_1b = 0
gen justice_active_mean_within_1b = 0
gen justice_absent_mean_within_1b = 0
gen justice_within_FE_1b_prior = .

gen absent_justice_case_j_ia = 0

local step_size = .

while `step_size' > 0.1^6 {

** Peer Effects Regression
* Peer effects, all other justices
if "`spec'" == "all" {
qui xtreg vote_direction justice_all_mean_within_1b i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.issueArea#i.term, fe vce(cluster caseId) nonest dfadj
est store b_within_all
}
* Peer effects, active justices only
if "`spec'" == "active" {
qui xtreg vote_direction justice_active_mean_within_1b i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.issueArea#i.term, fe vce(cluster caseId) nonest dfadj
est store b_within_active
}
* Peer effects, active and absent justices
if "`spec'" == "joint" {
qui xtreg vote_direction justice_active_mean_within_1b justice_absent_mean_within_1b absent_justice_case_j_ia i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.issueArea#i.term, fe vce(cluster caseId) nonest dfadj
est store b_within_joint
}

* Record Panel FE
estadd local absorbed_fe_jia =  cond(e(ivar) == "`panelvar_jia'","Yes","No",""), replace

* Full R-squared
predict uhat, e
qui summarize uhat
local uvar = r(Var)

qui summarize vote_direction if e(sample) == 1
local yvar = r(Var)

estadd scalar r2_full = 1 - `uvar'/`yvar'
drop uhat

est table b_within_`spec', stats(r2_full N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel


** Extract (Mean Zero) Fixed Effects 
est restore b_within_`spec'	
predict justice_within_FE_1b, u
* Ideology Estimates Standard Deviation
bysort issueArea: egen justice_within_FE_1b_mean = mean(justice_within_FE_1b) if !missing(vote_direction)
gen justice_within_FE_1b_normalised = justice_within_FE_1b - justice_within_FE_1b_mean if !missing(vote_direction)
qui summarize justice_within_FE_1b_normalised
estadd scalar sigma_justice = r(sd)
// Filter predictions down to out of sample cases (i.e. absent)
bysort justice issueArea (vote_direction): replace justice_within_FE_1b = justice_within_FE_1b[_n-1] if missing(justice_within_FE_1b)

drop justice_all_mean_within_1b justice_active_mean_within_1b justice_absent_mean_within_1b justice_active_mean_within_1b
drop justice_within_FE_1b_mean justice_within_FE_1b_normalised

* Normalise Justice FE to Baseline Mean (i.e. without Peer Effects)
// Note that adding/subtracting a constant is fully accounted for by the justice 
// FE in following estimation, no effect on peer effects estimate

bysort issueArea: egen justice_mean_new = mean(justice_within_FE_1b)
bysort issueArea: egen justice_mean_old = mean(justice_within_FE_1b_prior)

replace justice_within_FE_1b = justice_within_FE_1b - (justice_mean_new - justice_mean_old) if !missing(justice_within_FE_1b_prior)
drop justice_mean_new justice_mean_old


** Peer Variable Creation - b

* Mean of coefficient for all other justices
bysort casevote ever_ideology_justice_issue (voteId): egen justice_all_sum = total(justice_within_FE_1b)
bysort casevote ever_ideology_justice_issue (voteId): gen justice_all_mean_within_1b = (justice_all_sum - justice_within_FE_1b) / (_N - 1)
drop justice_all_sum

* Mean of coefficients for other active justices
bysort casevote active (voteId): egen justice_active_sum = total(justice_within_FE_1b)
bysort casevote active (voteId): gen justice_active_mean_within_1b = (justice_active_sum - justice_within_FE_1b) / (_N - 1)
drop justice_active_sum

* Mean of coefficients for absent justices
bysort ever_ideology_justice_issue issueArea: egen ideology_within_defined_mean_b = mean(justice_within_FE_1b)
bysort casevote ever_ideology_justice_issue (voteId): egen justice_absent_sum = total(justice_within_FE_1b * (1-active))
// Mean of absent justices (don't need leave out mean, since absent justices omitted anyway)
gen justice_absent_mean_within_1b = justice_absent_sum / number_absent_ideology_j_ia - ideology_within_defined_mean_b
// Subtracting mean defined ideology to provide natural zero for absent ideology
replace justice_absent_mean_within_1b = 0 if number_absent_ideology_j_ia == 0 // No absent judges
drop justice_absent_sum ideology_within_defined_mean_b

label variable justice_all_mean_within_1b "Mean All Peer Justices"
label variable justice_active_mean_within_1b "Mean Active Peer Justices"
label variable justice_absent_mean_within_1b "Mean Absent Peer Justices"


** Measure of change in justice ideology measure
gen justice_FE_change = justice_within_FE_1b - justice_within_FE_1b_prior
summarize justice_FE_change
local step_size = r(sd)
disp `step_size'
drop justice_FE_change

replace justice_within_FE_1b_prior = justice_within_FE_1b
replace absent_justice_case_j_ia = absent_justice_case_j_ia_temp // Initialise for iterations with peer variable

drop justice_within_FE_1b

}

* Save Final Iteration Results
frame copy default `spec'_b, replace	

}

est table b_within_all b_within_active b_within_joint, ///
	stats(r2_full N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel

esttab b_within_all b_within_active b_within_joint using Tables/table4b_within.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
	noomitted nobaselevels keep(justice_all_mean_within_1b justice_active_mean_within_1b justice_absent_mean_within_1b) stats(r2_full N, fmt(%9.4f %9.0g) labels(R-squared Observations)) legend label ///
	style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Ideology Results - Justice Vote Direction (Conservative $\%$)") replace

	
** 2c. Model 3 - Judge by issue area by natural court fixed effects, dummies for circuit court of appeal, issue area by term fixed effects, lower court decision

egen justiceIssueAreaNaturalCourt = group(justice issueArea naturalCourt)
xtset justiceIssueAreaNaturalCourt
local panelvar_jianc = r(panelvar)
local panelvar_jianc_name "Justice x Issue Area x Natural Court FE"

local specificationlist `" "all" "joint" "active" "'

foreach spec in `specificationlist' {

capture drop justice_all_mean_within_1c justice_active_mean_within_1c justice_absent_mean_within_1c justice_within_FE_1c_prior
capture drop absent_justice_case_j_ia_nc

* Initialise Peer Variables 
// Constant will be dropped
gen justice_all_mean_within_1c = 0
gen justice_active_mean_within_1c = 0
gen justice_absent_mean_within_1c = 0
gen justice_within_FE_1c_prior = .

gen absent_justice_case_j_ia_nc = 0

local step_size = .

while `step_size' > 0.1^6 {

** Peer Effects Regression
* Peer effects, all other justices
if "`spec'" == "all" {
qui xtreg vote_direction justice_all_mean_within_1c i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.issueArea#i.term, fe vce(cluster caseId) nonest dfadj
est store c_within_all
}
* Peer effects, active justices only
if "`spec'" == "active" {
qui xtreg vote_direction justice_active_mean_within_1c i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.issueArea#i.term, fe vce(cluster caseId) nonest dfadj
est store c_within_active
}
* Peer effects, active and absent justices
if "`spec'" == "joint" {
qui xtreg vote_direction justice_active_mean_within_1c justice_absent_mean_within_1c absent_justice_case_j_ia_nc i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.issueArea#i.term, fe vce(cluster caseId) nonest dfadj
est store c_within_joint
}

* Record Panel FE
estadd local absorbed_fe_jianc =  cond(e(ivar) == "`panelvar_jianc'","Yes","No",""), replace

* Full R-squared
predict uhat, e
qui summarize uhat
local uvar = r(Var)

qui summarize vote_direction if e(sample) == 1
local yvar = r(Var)

estadd scalar r2_full = 1 - `uvar'/`yvar'
drop uhat

est table c_within_`spec', stats(r2_full N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel


** Extract (Mean Zero) Fixed Effects 	
est restore c_within_`spec'
predict justice_within_FE_1c, u
* Ideology Estimates Standard Deviation
bysort issueArea naturalCourt: egen justice_within_FE_1c_mean = mean(justice_within_FE_1c) if !missing(vote_direction)
gen justice_within_FE_1c_normalised = justice_within_FE_1c - justice_within_FE_1c_mean if !missing(vote_direction)
qui summarize justice_within_FE_1c_normalised
estadd scalar sigma_justice = r(sd)
// Filter predictions down to out of sample cases (i.e. absent)
bysort justice issueArea naturalCourt (vote_direction): replace justice_within_FE_1c = justice_within_FE_1c[_n-1] if missing(justice_within_FE_1c)

drop justice_all_mean_within_1c justice_active_mean_within_1c justice_absent_mean_within_1c justice_active_mean_within_1c
drop justice_within_FE_1c_mean justice_within_FE_1c_normalised

* Normalise Justice FE to Baseline Mean (i.e. without Peer Effects)
// Note that adding/subtracting a constant by issue area - natural court pair
// is fully accounted for by the justice - issue area - natural court FE in 
// following estimation, no effect on peer effects estimate

bysort issueArea naturalCourt: egen justice_mean_new = mean(justice_within_FE_1c)
bysort issueArea naturalCourt: egen justice_mean_old = mean(justice_within_FE_1c_prior)

replace justice_within_FE_1c = justice_within_FE_1c - (justice_mean_new - justice_mean_old) if !missing(justice_within_FE_1c_prior)
drop justice_mean_new justice_mean_old


** Peer Variable Creation - c

* Mean of coefficient for all other justices
bysort casevote ever_ideology_justice_issue_nc (voteId): egen justice_all_sum = total(justice_within_FE_1c)
bysort casevote ever_ideology_justice_issue_nc (voteId): gen justice_all_mean_within_1c = (justice_all_sum - justice_within_FE_1c) / (_N - 1)
drop justice_all_sum

* Mean of coefficients for other active justices
bysort casevote active (voteId): egen justice_active_sum = total(justice_within_FE_1c)
bysort casevote active (voteId): gen justice_active_mean_within_1c = (justice_active_sum - justice_within_FE_1c) / (_N - 1)
drop justice_active_sum

* Mean of coefficients for absent justices
bysort ever_ideology_justice_issue_nc issueArea naturalCourt: egen ideology_within_defined_mean_c = mean(justice_within_FE_1c)
bysort casevote ever_ideology_justice_issue_nc (voteId): egen justice_absent_sum = total(justice_within_FE_1c * (1-active))
// Mean of absent justices (don't need leave out mean, since absent justices omitted anyway)
gen justice_absent_mean_within_1c = justice_absent_sum / number_absent_ideology_j_ia_nc - ideology_within_defined_mean_c
// Subtracting mean defined ideology to provide natural zero for absent ideology
replace justice_absent_mean_within_1c = 0 if number_absent_ideology_j_ia_nc == 0 // No absent judges
drop justice_absent_sum ideology_within_defined_mean_c

label variable justice_all_mean_within_1c "Mean All Peer Justices"
label variable justice_active_mean_within_1c "Mean Active Peer Justices"
label variable justice_absent_mean_within_1c "Mean Absent Peer Justices"


** Measure of change in justice ideology measure
gen justice_FE_change = justice_within_FE_1c - justice_within_FE_1c_prior
summarize justice_FE_change
local step_size = r(sd)
disp `step_size'
drop justice_FE_change

replace justice_within_FE_1c_prior = justice_within_FE_1c
replace absent_justice_case_j_ia_nc = absent_justice_case_j_ia_nc_temp // Initialise for iterations with peer variable

drop justice_within_FE_1c

}

* Save Final Iteration Results
frame copy default `spec'_c, replace

}

est table c_within_all c_within_active c_within_joint, ///
	stats(r2_full N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel

esttab c_within_all c_within_active c_within_joint using Tables/table4c_within.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
	noomitted nobaselevels keep(justice_all_mean_within_1c justice_active_mean_within_1c justice_absent_mean_within_1c) stats(r2_full N, fmt(%9.4f %9.0g) labels(R-squared Observations)) legend label ///
	style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Ideology Results - Justice Vote Direction (Conservative $\%$)") replace


** Coefficients on Other Controls of Interest
esttab a_within_active b_within_active c_within_active using Tables/table3.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
	noomitted nobaselevels drop(_cons *_mean_within_*) indicate("Term x Issue Area FE = *.issueArea#*.term" "Circuit Court FE = *.caseSource" "Issue Area FE = *.issueArea" "Term FE = *.term") stats(absorbed_fe_j absorbed_fe_jia absorbed_fe_jianc r2_full sigma_justice N, fmt(%3s %3s %3s %5.4f %5.4f %9.0g) labels("`panelvar_j_name'" "`panelvar_jia_name'" "`panelvar_jianc_name'" R-squared "Std. Dev. (Justice FEs)" Observations)) legend label ///
	style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("First Stage Results - Justice Vote Direction (Conservative $\%$)") replace
	
	
	
*** 3. Ideology Statistics

* Rename Variables
rename *_prior *

* Ideology Ranking (using First Stage Estimates with Term FE (Model B))
// Since this is what used to construct the peer measures
preserve

keep if !missing(vote_direction)
collapse (first) justice_FE_1a (first) scIdeology (mean) vote_direction (first) prespart, by(justice)
sort justice_FE_1a
list

tabout justice using Tables/table2.tex, ///
	cells(sum justice_FE_1a sum scIdeology sum vote_direction sum prespart) format(4 3 4 0) sum oneway style(tex) h2(\textbf{Justice} & \textbf{Ideology Estimate} & \textbf{Segal-Cover Score} & \textbf{Conservative Vote Proportion} & \textbf{Party of Appointing President} \\) h3(nil) ptotal(none) body replace
// Records value not label of president party, so replace manually
// Also need to sort justices manually

restore	

// Using non-within justice FE estimates here since don't want normalised to zero
// (Perfectly correlated once normalising with FE, so no effect on estimates)


*********** PEER EFFECTS WITH PREDETERMINED JUSTICE CHARACTERISTICS ************

*** 4a. Instrumenting Peer Variable with Segal-Cover scores

// Since all justices in sample have Segal-Cover score, no need to worry about defined ideology

// Don't need to normalize absent Segal-Cover measure for when justices are absent, 
// as this is a common level change whenever absent_justice_case = 0. 

frames dir
local frs = r(frames)
foreach fr in `frs' {
cwf `fr'

* Mean of Segal-Cover scores for all other justices
bysort casevote (voteId): egen scIdeology_all_sum = total(scIdeology)
bysort casevote (voteId): gen scIdeology_all_mean = (scIdeology_all_sum - scIdeology) / (_N - 1)
drop scIdeology_all_sum

* Mean of Segal-Cover scores for other active justices
bysort casevote active (voteId): egen scIdeology_active_sum = total(scIdeology)
bysort casevote active (voteId): gen scIdeology_active_mean = (scIdeology_active_sum - scIdeology) / (_N - 1)
drop scIdeology_active_sum

* Mean of Segal-Cover scores for absent justices
bysort casevote (voteId): egen scIdeology_absent_sum = total(scIdeology * (1-active))
// Mean of absent justices (don't need leave out mean, since absent justices omitted anyway)
gen scIdeology_absent_mean = scIdeology_absent_sum / number_absent
replace scIdeology_absent_mean = 0 if number_absent == 0 // No absent judges
drop scIdeology_absent_sum

label variable scIdeology_all_mean "Segal Cover Mean All Peer Justices"
label variable scIdeology_active_mean "Segal Cover Mean Active Peer Justices"
label variable scIdeology_absent_mean "Segal Cover Mean Absent Peer Justices"

}

cwf default


** Instrumental Variables Regressions for Justice FE Models

** Model 1

local specificationlist `" "all" "joint" "active" "'

foreach spec in `specificationlist' {


** Peer Effects Regression
* Peer effects, all other justices
if "`spec'" == "all" {
cwf `spec'_a 

qui ivregress 2sls vote_direction (justice_all_mean_within_1a = scIdeology_all_mean) i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId) first
est store iv_a_`spec'
estat firststage
mat fsFStat = r(singleresults)
estadd scalar fsFStat = fsFStat[1,4] 

cwf default
}
* Peer effects, active justices only
if "`spec'" == "active" {
cwf `spec'_a 

qui ivregress 2sls vote_direction (justice_active_mean_within_1a = scIdeology_active_mean) i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId) first
est store iv_a_`spec'
estat firststage
mat fsFStat = r(singleresults)
estadd scalar fsFStat = fsFStat[1,4] 

cwf default
}
* Peer effects, active and absent justices
if "`spec'" == "joint" {
cwf `spec'_a 

qui ivregress 2sls vote_direction (justice_active_mean_within_1a justice_absent_mean_within_1a = scIdeology_active_mean scIdeology_absent_mean) absent_justice_case_j absent_justice_case i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId) first
est store iv_a_`spec'

cwf default
}

}
	
est table iv_a_all iv_a_active iv_a_joint, ///
	stats(fsFStat N) keep(justice_* absent_justice_case) b(%9.4f) t(%9.3f) stfmt(%9.2f) varlabel

esttab iv_a_all iv_a_active iv_a_joint using Tables/table5a.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
	noomitted nobaselevels keep(justice_all_mean_within_1a justice_active_mean_within_1a justice_absent_mean_within_1a) stats(fsFStat N, fmt(%9.2f %9.0g) labels("First Stage F-Statistic" Observations)) legend label ///
	style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Ideology IV (Segal-Cover) Results - Justice Vote Direction (Conservative $\%$)") replace

	
************************ EXOGENEITY OF JUSTICE ABSENCES ************************

*** Correlation of absent justice ideologies

cwf active_a

rename *_prior *

* Multiple Absence Frequency
preserve

* Case-Issue Pairs
bysort casevote: keep if _n == 1
count if directional == 1
tab number_absent if directional == 1
tab number_absent if directional == 1 & number_absent != 0

* Cases
bysort caseId (directional number_absent): keep if _n == _N
tab number_absent if directional == 1
tab number_absent if directional == 1 & number_absent != 0

restore

* Correct Leave-Out Absent Peer Mean for Absent Justices
bysort ever_ideology_justice: egen ideology_defined_mean_a = mean(justice_within_FE_1a)
bysort casevote ever_ideology_justice (voteId): egen justice_absent_sum = total(justice_within_FE_1a * (1-active))
* Leave out mean of absent justices (to also get absent peer meaan for absent justices)
gen justice_absent_mean_1a_lo = (justice_absent_sum - justice_within_FE_1a * (1-active))  / (number_absent_ideology_j - (1-active)) - ideology_defined_mean_a
// Subtracting mean defined ideology to provide natural zero for absent ideology
replace justice_absent_mean_1a_lo = 0 if number_absent_ideology_j == 0 // No absent judges with defined ideology
drop justice_absent_sum ideology_defined_mean_a

* Once other justices are considered absent, mean of remaining pool (active and considered absent) that choice is from
bysort casevote active (voteId): egen justice_active_sum = total(justice_within_FE_1a) if active == 1
gsort casevote -active
by casevote: replace justice_active_sum = justice_active_sum[_n-1] if missing(justice_active_sum) 

gen justice_choice_sum = justice_active_sum + justice_within_FE_1a * (1-active) if active == 0 & directional == 1
gen justice_choice_mean_1a = justice_choice_sum / (number_active + (1-active)) if active == 0 & directional == 1
drop justice_active_sum

* Pooled Regression
reg justice_within_FE_1a justice_absent_mean_1a_lo justice_choice_mean_1a if directional == 1 & active == 0 & number_absent_ideology_j >= 2, vce(cluster caseId)
* First Year Absences
reg justice_within_FE_1a justice_absent_mean_1a_lo justice_choice_mean_1a if directional == 1 & active == 0 & number_absent_ideology_j >= 2 & tenure == 1, vce(cluster caseId)
* Established Justices
reg justice_within_FE_1a justice_absent_mean_1a_lo justice_choice_mean_1a if directional == 1 & active == 0 & number_absent_ideology_j >= 2 & tenure != 1, vce(cluster caseId)

cwf default


** Selection on Observables
reg justice_absent_mean_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection if absent_justice_case == 1 & directional == 1, vce(cluster caseId)


**************** MOFFIT REDUCED FORM PEER EFFECTS SPECFICIATION ****************

* Add first stage of IV strategy in peer vote section to estimate full reduced 
* form, including both peer ideology measures and peer home court measures.

* Focus on Model B as basic specification, use home status of all peers for this
* exercise, estimate using OLS (since Segal-Cover instruments had little effect).

*** Instruments

** Home Court Variables, All justices
* Proportion of all other justices at case home
bysort casevote: egen homeCircuitCourt_all_sum = total(homeCircuitCourt)
bysort casevote: gen homeCircuitCourt_all_ave = (homeCircuitCourt_all_sum - homeCircuitCourt) / (_N - 1)
label var homeCircuitCourt_all_ave "Share of Peers at Home"

* Average years other justices at case home (i.e. weighted by circuit court tenure)
bysort casevote: egen homeCircuitCourtYears_all_sum = total(homeCircuitCourtYears)
bysort casevote: gen homeCircuitCourtYears_all_ave = (homeCircuitCourtYears_all_sum - homeCircuitCourtYears) / (_N - 1)
label var homeCircuitCourtYears_all_ave "Peer Mean Years at Home"


** 5a. Model 1 - Judge fixed effect, dummies for circuit court of appeal, year, issue area, lower court decision

xtset justice
local panelvar_j = r(panelvar)
local panelvar_j_name "Justice FE"

local specificationlist `" "all" "joint" "active" "'

foreach spec in `specificationlist' {

capture drop justice_all_mean_moffit_1a justice_active_mean_moffit_1a justice_absent_mean_moffit_1a justice_FE_1a_moffit_prior
capture drop absent_justice_case_j
	
* Initialise Peer Variables 
// Constant will be dropped
gen justice_all_mean_moffit_1a = 0
gen justice_active_mean_moffit_1a = 0
gen justice_absent_mean_moffit_1a = 0
gen justice_FE_1a_moffit_prior = .

gen absent_justice_case_j = 0

local step_size = .

while `step_size' > 0.1^6 {

** Peer Effects Regression
* Peer effects, all other justices
if "`spec'" == "all" {
qui xtreg vote_direction justice_all_mean_moffit_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection i.term, fe vce(cluster caseId) nonest dfadj
est store a_moffit_all
}
* Peer effects, active justices only
if "`spec'" == "active" {
qui xtreg vote_direction justice_active_mean_moffit_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection i.term, fe vce(cluster caseId) nonest dfadj
est store a_moffit_active
}
* Peer effects, active and absent justices
if "`spec'" == "joint" {
qui xtreg vote_direction justice_active_mean_moffit_1a justice_absent_mean_moffit_1a absent_justice_case_j i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection i.term, fe vce(cluster caseId) nonest dfadj
est store a_moffit_joint
}

* F-test of Instruments
test c.homeCircuitCourt_all_ave#1.lcDispositionDirection c.homeCircuitCourt_all_ave#2.lcDispositionDirection c.homeCircuitCourtYears_all_ave#1.lcDispositionDirection c.homeCircuitCourtYears_all_ave#2.lcDispositionDirection
estadd scalar iFStat = r(F)
estadd scalar iPVal = r(p)

* Record Panel FE
estadd local absorbed_fe_j =  cond(e(ivar) == "`panelvar_j'","Yes","No",""), replace

* Full R-squared
predict uhat, e
qui summarize uhat
local uvar = r(Var)

qui summarize vote_direction if e(sample) == 1
local yvar = r(Var)

estadd scalar r2_full = 1 - `uvar'/`yvar'
drop uhat

est table a_moffit_`spec', stats(r2_full N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel


** Extract (Mean Zero) Fixed Effects 
est restore a_moffit_`spec'
predict justice_FE_1a_moffit, u
qui summarize justice_FE_1a_moffit
estadd scalar sigma_justice = r(sd)
// Filter predictions down to out of sample cases (i.e. absent)
bysort justice (vote_direction): replace justice_FE_1a_moffit = justice_FE_1a_moffit[_n-1] if missing(justice_FE_1a_moffit)

drop justice_all_mean_moffit_1a justice_active_mean_moffit_1a justice_absent_mean_moffit_1a justice_active_mean_moffit_1a

* Normalise Justice FE to Baseline Mean (i.e. without Peer Effects)
// Note that adding/subtracting a constant is fully accounted for by the justice 
// FE in following estimation, no effect on peer effects estimate

egen justice_mean_new = mean(justice_FE_1a_moffit)
egen justice_mean_old = mean(justice_FE_1a_moffit_prior)

replace justice_FE_1a_moffit = justice_FE_1a_moffit - (justice_mean_new - justice_mean_old) if !missing(justice_FE_1a_moffit_prior)
drop justice_mean_new justice_mean_old


** Peer Variable Creation - a

* Mean of coefficient for all other justices
bysort casevote ever_ideology_justice (voteId): egen justice_all_sum = total(justice_FE_1a_moffit)
bysort casevote ever_ideology_justice (voteId): gen justice_all_mean_moffit_1a = (justice_all_sum - justice_FE_1a_moffit) / (_N - 1)
drop justice_all_sum

* Mean of coefficients for other active justices
bysort casevote active (voteId): egen justice_active_sum = total(justice_FE_1a_moffit)
bysort casevote active (voteId): gen justice_active_mean_moffit_1a = (justice_active_sum - justice_FE_1a_moffit) / (_N - 1)
drop justice_active_sum

* Mean of coefficients for absent justices
bysort ever_ideology_justice: egen ideology_moffit_defined_mean_a = mean(justice_FE_1a_moffit)
bysort casevote ever_ideology_justice (voteId): egen justice_absent_sum = total(justice_FE_1a_moffit * (1-active))
// Mean of absent justices (don't need leave out mean, since absent justices omitted anyway)
gen justice_absent_mean_moffit_1a = justice_absent_sum / number_absent_ideology_j - ideology_moffit_defined_mean_a
// Subtracting mean defined ideology to provide natural zero for absent ideology
replace justice_absent_mean_moffit_1a = 0 if number_absent_ideology_j == 0 // No absent judges with defined ideology
drop justice_absent_sum ideology_moffit_defined_mean_a

label variable justice_all_mean_moffit_1a "Mean All Peer Justices"
label variable justice_active_mean_moffit_1a "Mean Active Peer Justices"
label variable justice_absent_mean_moffit_1a "Mean Absent Peer Justices"


** Measure of change in justice ideology measure
gen justice_FE_change = justice_FE_1a_moffit - justice_FE_1a_moffit_prior
summarize justice_FE_change
local step_size = r(sd)
disp `step_size'
drop justice_FE_change

replace justice_FE_1a_moffit_prior = justice_FE_1a_moffit
replace absent_justice_case_j = absent_justice_case_j_temp // Initialise for iterations with peer variable

drop justice_FE_1a_moffit

}

* Save Final Iteration Results
frame copy default moffit_`spec'_a, replace	

}


est table a_moffit_all a_moffit_active a_moffit_joint, ///
	stats(r2_full N iFStat iPVal) keep(justice_* c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection) b(%9.4f) t(%9.3f) varlabel
	
esttab a_moffit_all a_moffit_active a_moffit_joint using Tables/table6a_moffit.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
	noomitted nobaselevels keep(justice_all_mean_moffit_1a justice_active_mean_moffit_1a justice_absent_mean_moffit_1a *.lcDispositionDirection#*.homeCircuitCourt_all_ave *.lcDispositionDirection#*.homeCircuitCourtYears_all_ave) order(justice_*) stats(r2_full N iFStat iPVal, fmt(%9.4f %9.0g %9.3f %5.4f) labels(R-squared Observations "Instruments F-Statistic" "Instrument P-Value")) legend label ///
	style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Reduced Form Peer Effects - Justice Vote Direction (Conservative $\%$)") replace type
 
drop homeCircuitCourt_all_sum homeCircuitCourtYears_all_sum homeCircuitCourt_all_ave homeCircuitCourtYears_all_ave


********************** PEER EFFECT ON VOTES WITHIN CASE ************************

local graphnumber = `graphnumber' + 1

* Estimating effect of peers votes on own votes directly, compared to the more 
* general mechanism of shifting ideology above.

** Mean Vote of Other Justices within case
bysort casevote active: egen vote_sum = total(vote_direction)
bysort casevote active: gen other_vote_mean = (vote_sum - vote_direction) / (_N - 1)
label var other_vote_mean "Peer Vote Mean"
drop vote_sum

* Mean Vote (Including Self) within case
bysort casevote active: egen vote_mean = mean(vote_direction)


*** 6. Peer Circuit Court Relationships as Instrument for Mean Votes

* Restore default omitted year dummy to first since estimating without constant
fvset base first term

** All justices
* Proportion of all other justices at case home
bysort casevote: egen homeCircuitCourt_all_sum = total(homeCircuitCourt)
bysort casevote: gen homeCircuitCourt_all_ave = (homeCircuitCourt_all_sum - homeCircuitCourt) / (_N - 1)
*label var homeCircuitCourt_all_ave "Proportion of Peer Justices at Home Circuit Court"
label var homeCircuitCourt_all_ave "Share of Peers at Home"

* Average years other justices at case home (i.e. weighted by circuit court tenure)
bysort casevote: egen homeCircuitCourtYears_all_sum = total(homeCircuitCourtYears)
bysort casevote: gen homeCircuitCourtYears_all_ave = (homeCircuitCourtYears_all_sum - homeCircuitCourtYears) / (_N - 1)
*label var homeCircuitCourtYears_all_ave "Years of Home Circuit Court Tenure per Peer"
label var homeCircuitCourtYears_all_ave "Peer Mean Years at Home"

** Active justices
* Proportion of other active justices at case home
bysort casevote active: egen homeCircuitCourt_active_sum = total(homeCircuitCourt)
bysort casevote active: gen homeCircuitCourt_active_ave = (homeCircuitCourt_active_sum - homeCircuitCourt) / (_N - 1)
*label var homeCircuitCourt_active_ave "Proportion of Active Peer Justices at Home Circuit Court"
label var homeCircuitCourt_active_ave "Share of Active Peers at Home"

* Average years other active justices at case home (i.e. weighted by circuit court tenure)
bysort casevote active: egen homeCircuitCourtYears_active_sum = total(homeCircuitCourtYears)
bysort casevote active: gen homeCircuitCourtYears_active_ave = (homeCircuitCourtYears_active_sum - homeCircuitCourtYears) / (_N - 1)
*label var homeCircuitCourtYears_active_ave "Years of Home Circuit Court Tenure per Active Peer"
label var homeCircuitCourtYears_active_ave "Active Peer Mean Years at Home"

// Average years at home per active justice, not per justice at home. Upward effect of homeCircuitCourt_active_ave is summed for each 
// justice, so offset should be summed across justices as well. Doing average tenure for at home justices only slows offset but not 
//the intial upward effect when multiple justices at home. 


** Options for First Stage LHS (Ie endogenous variable)
* Net proportion of other at home votes (share in direction 1 less share in direction 0) 
* Average vote of other home justices
* Mean of all other votes

* Net Vote Proportion other home justices votes within case
// Only include in first stage if other justice, and at home
// Construct so votes in equally divided courts are counted (but cancel out in net)
bysort casevote active: egen home_lib_vote_sum = total((1 - vote_direction)*homeCircuitCourt)
bysort casevote active: egen home_con_vote_sum = total(vote_direction*homeCircuitCourt)

bysort casevote active: gen other_home_lib_vote_mean = (home_lib_vote_sum - (1-vote_direction)*homeCircuitCourt) / (_N - 1)
bysort casevote active: gen other_home_con_vote_mean = (home_con_vote_sum - vote_direction*homeCircuitCourt) / (_N - 1)
bysort casevote active: gen other_home_net_vote_mean = other_home_con_vote_mean - other_home_lib_vote_mean if active == 1 // Net vote (conservative, net of liberal) of active home justices
label var other_home_net_vote_mean "Net Home Peer Vote Mean"

* Mean Vote of other home justices
gen other_home_vote_mean = other_home_con_vote_mean / homeCircuitCourt_active_ave if active == 1 // Share of active home justices vote conservative
replace other_home_vote_mean = 0 if homeCircuitCourt_active_ave == 0 & active == 1 // Set to zero if no active other home justices 
label var other_home_vote_mean "Home Peer Vote Mean"
drop home_lib_vote_sum home_con_vote_sum other_home_lib_vote_mean other_home_con_vote_mean homeCircuitCourt_active_sum

* Indicator for case with (other) active home justice
bysort casevote active: gen other_home_active_case = homeCircuitCourt_active_ave > 0 & active == 1
// Always use whether active justices are home since endogenous measures are always votes of active justices
// (i.e. aim to isolate identifying variation in LHS variable, not to be consistent with all/active status of instruments)

// other_home_active_case is used as an intercept for other_home_vote_mean and other_home_net_vote_mean to account 
// for the fact that if 0 others are home, mean vote of these is mechanically zero, but if positive 
// number of others are home, need not be true (for other_home_vote_mean, mean vote is typically around half, 
// for other_home_net_vote_mean, so as to avoid identifying from mean vote not being exactly half).
// Thus instruments picking up identification only from variation conditional upon at least one other home.


*** IV Estimates

// Note that still captures effect of active votes (since these are the only votes 
// that can be measured), just using all/active as instruments.

xtset justice


** Other Vote Mean as Endogenous Variable

local specificationlist `" "all" "active" "'

foreach spec in `specificationlist' {

capture drop justice_active_mean_votes_1a justice_votes_FE_1a_prior
	
* Initialise Peer Variables 
// Constant will be dropped
gen justice_active_mean_votes_1a = 0
gen justice_votes_FE_1a_prior = .

local step_size = .

while `step_size' > 0.1^6 {

** Peer Effects Regression
* Peer effects, all other justices
if "`spec'" == "all" {
qui xtivreg vote_direction (other_vote_mean = c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection) justice_active_mean_votes_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, fe vce(robust) first
est store vote_mean_all_a
}
* Peer effects, active justices only
if "`spec'" == "active" {
qui xtivreg vote_direction (other_vote_mean = c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection) justice_active_mean_votes_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, fe vce(robust) first
est store vote_mean_active_a
}

est table vote_mean_`spec'_a, stats(r2 N) keep(other_vote_mean justice_*) b(%9.4f) t(%9.3f) varlabel

** Extract (Mean Zero) Fixed Effects 
est restore vote_mean_`spec'_a
predict justice_votes_FE_1a, u
qui summarize justice_votes_FE_1a
// Filter predictions down to out of sample cases (i.e. absent)
bysort justice (vote_direction): replace justice_votes_FE_1a = justice_votes_FE_1a[_n-1] if missing(justice_votes_FE_1a)

drop justice_active_mean_votes_1a

* Normalise Justice FE to Baseline Mean (i.e. without Peer Effects)
// Note that adding/subtracting a constant is fully accounted for by the justice 
// FE in following estimation, no effect on peer effects estimate

egen justice_mean_new = mean(justice_votes_FE_1a)
egen justice_mean_old = mean(justice_votes_FE_1a_prior)

replace justice_votes_FE_1a = justice_votes_FE_1a - (justice_mean_new - justice_mean_old) if !missing(justice_votes_FE_1a_prior)
drop justice_mean_new justice_mean_old


** Peer Variable Creation - a

* Mean of coefficients for other active justices
bysort casevote active (voteId): egen justice_active_sum = total(justice_votes_FE_1a)
bysort casevote active (voteId): gen justice_active_mean_votes_1a = (justice_active_sum - justice_votes_FE_1a) / (_N - 1)
drop justice_active_sum

label variable justice_active_mean_votes_1a "Mean Active Peer Justices"


** Measure of change in justice ideology measure
gen justice_FE_change = justice_votes_FE_1a - justice_votes_FE_1a_prior
summarize justice_FE_change
local step_size = r(sd)
disp `step_size'
drop justice_FE_change

replace justice_votes_FE_1a_prior = justice_votes_FE_1a

drop justice_votes_FE_1a

}


** Final Results with Correct Standard Errors

* All justices at home
if "`spec'" == "all" {
qui ivregress 2sls vote_direction (other_vote_mean = c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection) justice_active_mean_votes_1a i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId) first
est store vote_mean_all_a
estat firststage
mat fsFStat = r(singleresults)
estadd scalar fs = fsFStat[1,4] 

* First Stage Instruments Significance
qui reg other_vote_mean c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection justice_active_mean_votes_1a i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
testparm c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection
estadd scalar fs_f = r(F)
estadd scalar fs_p = r(p)
est store fs_vote_mean_all_a

}
* Active justices at home
if "`spec'" == "active" {
qui ivregress 2sls vote_direction (other_vote_mean = c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection) justice_active_mean_votes_1a i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId) first
est store vote_mean_active_a
estat firststage
mat fsFStat = r(singleresults)
estadd scalar fs = fsFStat[1,4] 

* First Stage Instruments Significance
qui reg other_vote_mean c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection justice_active_mean_votes_1a i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
testparm c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection
estadd scalar fs_f = r(F)
estadd scalar fs_p = r(p)
est store fs_vote_mean_active_a
}

}

est table vote_mean_all_a vote_mean_active_a, ///
	stats(N r2 fs) keep(other_vote_mean justice_active_mean_votes_1a) b(%9.4f) t(%9.3f) varlabel

esttab vote_mean_all_a vote_mean_active_a using Tables/table8a.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
noomitted nobaselevels keep(other_vote_mean justice_active_mean_votes_1a) stats(N fs, fmt(%9.0g %9.3f) labels(Observations "First Stage F-Statistic")) legend label ///
style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Vote Effects IV Second Stage - Justice Vote Direction (Conservative $\%$)") replace
	

* First Stage Regression Tables - Other Vote Mean
est table fs_vote_mean_all_a fs_vote_mean_active_a, ///
	stats(N r2 fs_f fs_p) keep(c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection justice_active_mean_votes_1a) b(%9.4f) t(%9.3f) varlabel
	
esttab fs_vote_mean_all_a fs_vote_mean_active_a using Tables/table7a.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
noomitted keep(*.lcDispositionDirection#*.homeCircuitCourt_all_ave *.lcDispositionDirection#*.homeCircuitCourtYears_all_ave *.lcDispositionDirection#*.homeCircuitCourt_active_ave *.lcDispositionDirection#*.homeCircuitCourtYears_active_ave) ///
stats(r2 N fs_f fs_p, fmt(%9.4f %9.0g %9.3f %9.3f) labels(R-squared Observations "First Stage F-Statistic" "First Stage P-Value")) legend label ///
style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Vote Effects IV First Stage - Peer Vote Measures") replace


** Mean At-Home Vote as Endogenous Variable

local specificationlist `" "all" "active" "'

foreach spec in `specificationlist' {

capture drop justice_active_mean_votes_1a justice_votes_FE_1a_prior
	
* Initialise Peer Variables 
// Constant will be dropped
gen justice_active_mean_votes_1a = 0
gen justice_votes_FE_1a_prior = .

local step_size = .

while `step_size' > 0.1^6 {

** Peer Effects Regression
* Peer effects, all other justices
if "`spec'" == "all" {
qui xtivreg vote_direction (other_home_vote_mean = c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection) other_home_active_case justice_active_mean_votes_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, fe vce(robust) first
est store home_vote_all_a
}
* Peer effects, active justices only
if "`spec'" == "active" {
qui xtivreg vote_direction (other_home_vote_mean = c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection) other_home_active_case justice_active_mean_votes_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, fe vce(robust) first
est store home_vote_active_a
}

est table home_vote_`spec'_a, stats(r2 N) keep(other_home_vote_mean justice_*) b(%9.4f) t(%9.3f) varlabel


** Extract (Mean Zero) Fixed Effects 
est restore home_vote_`spec'_a
predict justice_votes_FE_1a, u
qui summarize justice_votes_FE_1a
// Filter predictions down to out of sample cases (i.e. absent)
bysort justice (vote_direction): replace justice_votes_FE_1a = justice_votes_FE_1a[_n-1] if missing(justice_votes_FE_1a)

drop justice_active_mean_votes_1a

* Normalise Justice FE to Baseline Mean (i.e. without Peer Effects)
// Note that adding/subtracting a constant is fully accounted for by the justice 
// FE in following estimation, no effect on peer effects estimate

egen justice_mean_new = mean(justice_votes_FE_1a)
egen justice_mean_old = mean(justice_votes_FE_1a_prior)

replace justice_votes_FE_1a = justice_votes_FE_1a - (justice_mean_new - justice_mean_old) if !missing(justice_votes_FE_1a_prior)
drop justice_mean_new justice_mean_old


** Peer Variable Creation - a

* Mean of coefficients for other active justices
bysort casevote active (voteId): egen justice_active_sum = total(justice_votes_FE_1a)
bysort casevote active (voteId): gen justice_active_mean_votes_1a = (justice_active_sum - justice_votes_FE_1a) / (_N - 1)
drop justice_active_sum

label variable justice_active_mean_votes_1a "Mean Active Peer Justices"


** Measure of change in justice ideology measure
gen justice_FE_change = justice_votes_FE_1a - justice_votes_FE_1a_prior
summarize justice_FE_change
local step_size = r(sd)
disp `step_size'
drop justice_FE_change

replace justice_votes_FE_1a_prior = justice_votes_FE_1a

drop justice_votes_FE_1a

}


** Final Results with Correct Standard Errors

* All justices at home
if "`spec'" == "all" {
qui ivregress 2sls vote_direction (other_home_vote_mean = c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection) other_home_active_case justice_active_mean_votes_1a i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId) first
est store home_vote_all_a
estat firststage
mat fsFStat = r(singleresults)
estadd scalar fs = fsFStat[1,4] 

* First Stage Instruments Significance
qui reg other_home_vote_mean c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection other_home_active_case justice_active_mean_votes_1a i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
testparm c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection
estadd scalar fs_f = r(F)
estadd scalar fs_p = r(p)
est store fs_home_vote_all_a

}

* Active justices at home
if "`spec'" == "active" {
qui ivregress 2sls vote_direction (other_home_vote_mean = c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection) other_home_active_case justice_active_mean_votes_1a i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId) first
est store home_vote_active_a
estat firststage
mat fsFStat = r(singleresults)
estadd scalar fs = fsFStat[1,4] 

* First Stage Instruments Significance
qui reg other_home_vote_mean c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection other_home_active_case justice_active_mean_votes_1a i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
testparm c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection
estadd scalar fs_f = r(F)
estadd scalar fs_p = r(p)
est store fs_home_vote_active_a

}

}

est table home_vote_all_a home_vote_active_a, ///
	stats(N fs) keep(other_home_vote_mean other_home_active_case justice_active_mean_votes_1a) b(%9.4f) t(%9.3f) varlabel

esttab home_vote_all_a home_vote_active_a using Tables/table8b.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
noomitted nobaselevels keep(other_home_vote_mean justice_active_mean_votes_1a) stats(N fs, fmt(%9.0g %9.3f) labels("First Stage F-Statistic")) legend label ///
style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Vote Effects IV Second Stage - Justice Vote Direction (Conservative $\%$)") replace


* First Stage Regression Tables - Mean At-Home Vote
est table fs_home_vote_all_a fs_home_vote_active_a, ///
	stats(N r2 fs_f fs_p) keep(c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection justice_active_mean_votes_1a) b(%9.4f) t(%9.3f) varlabel
	
esttab fs_home_vote_all_a fs_home_vote_active_a using Tables/table7b.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
noomitted keep(*.lcDispositionDirection#*.homeCircuitCourt_all_ave *.lcDispositionDirection#*.homeCircuitCourtYears_all_ave *.lcDispositionDirection#*.homeCircuitCourt_active_ave *.lcDispositionDirection#*.homeCircuitCourtYears_active_ave) ///
stats(r2 N fs_f fs_p, fmt(%9.4f %9.0g %9.3f %9.3f) labels(R-squared Observations "First Stage F-Statistic" "First Stage P-Value")) legend label ///
style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Vote Effects IV First Stage - Peer Vote Measures") replace


** Net At-Home Vote as Endogenous Variable

local specificationlist `" "all" "active" "'

foreach spec in `specificationlist' {

capture drop justice_active_mean_votes_1a justice_votes_FE_1a_prior
	
* Initialise Peer Variables 
// Constant will be dropped
gen justice_active_mean_votes_1a = 0
gen justice_votes_FE_1a_prior = .

local step_size = .

while `step_size' > 0.1^6 {

** Peer Effects Regression
* Peer effects, all other justices
if "`spec'" == "all" {
qui xtivreg vote_direction (other_home_net_vote_mean = c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection) other_home_active_case justice_active_mean_votes_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, fe vce(robust) first
est store home_net_vote_all_a
}
* Peer effects, active justices only
if "`spec'" == "active" {
qui xtivreg vote_direction (other_home_net_vote_mean = c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection) other_home_active_case justice_active_mean_votes_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, fe vce(robust) first
est store home_net_vote_active_a
}

est table home_net_vote_`spec'_a, stats(r2 N) keep(other_home_net_vote_mean justice_*) b(%9.4f) t(%9.3f) varlabel


** Extract (Mean Zero) Fixed Effects 
est restore home_net_vote_`spec'_a
predict justice_votes_FE_1a, u
qui summarize justice_votes_FE_1a
// Filter predictions down to out of sample cases (i.e. absent)
bysort justice (vote_direction): replace justice_votes_FE_1a = justice_votes_FE_1a[_n-1] if missing(justice_votes_FE_1a)

drop justice_active_mean_votes_1a

* Normalise Justice FE to Baseline Mean (i.e. without Peer Effects)
// Note that adding/subtracting a constant is fully accounted for by the justice 
// FE in following estimation, no effect on peer effects estimate

egen justice_mean_new = mean(justice_votes_FE_1a)
egen justice_mean_old = mean(justice_votes_FE_1a_prior)

replace justice_votes_FE_1a = justice_votes_FE_1a - (justice_mean_new - justice_mean_old) if !missing(justice_votes_FE_1a_prior)
drop justice_mean_new justice_mean_old


** Peer Variable Creation - a

* Mean of coefficients for other active justices
bysort casevote active (voteId): egen justice_active_sum = total(justice_votes_FE_1a)
bysort casevote active (voteId): gen justice_active_mean_votes_1a = (justice_active_sum - justice_votes_FE_1a) / (_N - 1)
drop justice_active_sum

label variable justice_active_mean_votes_1a "Mean Active Peer Justices"


** Measure of change in justice ideology measure
gen justice_FE_change = justice_votes_FE_1a - justice_votes_FE_1a_prior
summarize justice_FE_change
local step_size = r(sd)
disp `step_size'
drop justice_FE_change

replace justice_votes_FE_1a_prior = justice_votes_FE_1a

drop justice_votes_FE_1a

}


** Final Results with Correct Standard Errors

* All justices at home
if "`spec'" == "all" {
qui ivregress 2sls vote_direction (other_home_net_vote_mean = c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection) other_home_active_case justice_active_mean_votes_1a i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId) first
est store home_net_vote_all_a
estat firststage
mat fsFStat = r(singleresults)
estadd scalar fs = fsFStat[1,4] 

* First Stage Instruments Significance
qui reg other_home_net_vote_mean c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection other_home_active_case justice_active_mean_votes_1a i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
testparm c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection
estadd scalar fs_f = r(F)
estadd scalar fs_p = r(p)
est store fs_home_net_vote_all_a

}

* Active justices at home
if "`spec'" == "active" {
qui ivregress 2sls vote_direction (other_home_net_vote_mean = c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection) other_home_active_case justice_active_mean_votes_1a i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId) first
est store home_net_vote_active_a
estat firststage
mat fsFStat = r(singleresults)
estadd scalar fs = fsFStat[1,4] 

* First Stage Instruments Significance
qui reg other_home_net_vote_mean c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection other_home_active_case justice_active_mean_votes_1a i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
testparm c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection
estadd scalar fs_f = r(F)
estadd scalar fs_p = r(p)
est store fs_home_net_vote_active_a

}

}

est table home_net_vote_all_a home_net_vote_active_a, ///
	stats(N r2 fs) keep(other_home_net_vote_mean justice_active_mean_votes_1a) b(%9.4f) t(%9.3f) varlabel

esttab home_net_vote_all_a home_net_vote_active_a using Tables/table8c.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
noomitted nobaselevels keep(other_home_net_vote_mean justice_active_mean_votes_1a) stats(N fs, fmt(%9.0g %9.3f) labels(Observations "First Stage F-Statistic")) legend label ///
style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Vote Effects IV Second Stage - Justice Vote Direction (Conservative $\%$)") replace


* First Stage Regression Tables - Net At-Home Vote
est table fs_home_net_vote_all_a fs_home_net_vote_active_a, ///
	stats(N r2 fs_f fs_p) keep(c.homeCircuitCourt_all_ave#i.lcDispositionDirection c.homeCircuitCourtYears_all_ave#i.lcDispositionDirection c.homeCircuitCourt_active_ave#i.lcDispositionDirection c.homeCircuitCourtYears_active_ave#i.lcDispositionDirection justice_active_mean_votes_1a) b(%9.4f) t(%9.3f) varlabel
	
esttab fs_home_net_vote_all_a fs_home_net_vote_active_a using Tables/table7c.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
noomitted keep(*.lcDispositionDirection#*.homeCircuitCourt_all_ave *.lcDispositionDirection#*.homeCircuitCourtYears_all_ave *.lcDispositionDirection#*.homeCircuitCourt_active_ave *.lcDispositionDirection#*.homeCircuitCourtYears_active_ave) ///
stats(r2 N fs_f fs_p, fmt(%9.4f %9.0g %9.3f %9.3f) labels(R-squared Observations "First Stage F-Statistic" "First Stage P-Value")) legend label ///
style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Vote Effects IV First Stage - Peer Vote Measures") replace


** Combined Tables of Results
* Second Stage IV
esttab vote_mean_all_a vote_mean_active_a home_vote_all_a home_vote_active_a home_net_vote_all_a home_net_vote_active_a using Tables/table8.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
noomitted nobaselevels keep(other_vote_mean other_home_vote_mean other_home_net_vote_mean justice_active_mean_votes_1a) order(other_vote_mean other_home_vote_mean other_home_net_vote_mean justice_active_mean_1a) stats(N fs, fmt(%9.0g %9.3f) labels(Observations "First Stage F-Statistic")) legend label ///
style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Vote Effects IV Second Stage - Justice Vote Direction (Conservative $\%$)") replace
* First Stage IV
esttab fs_vote_mean_all_a fs_vote_mean_active_a fs_home_vote_all_a fs_home_vote_active_a fs_home_net_vote_all_a fs_home_net_vote_active_a using Tables/table7.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
noomitted keep(*.lcDispositionDirection#*.homeCircuitCourt_all_ave *.lcDispositionDirection#*.homeCircuitCourtYears_all_ave *.lcDispositionDirection#*.homeCircuitCourt_active_ave *.lcDispositionDirection#*.homeCircuitCourtYears_active_ave) /// 
stats(r2 N fs_f fs_p, fmt(%9.4f %9.0g %9.3f %9.4f) labels(R-squared Observations "First Stage F-Statistic" "First Stage P-Value")) legend label wrap varwidth(30) ///
mgroups("Other Vote Mean" "Other Home Vote Mean" "Other Net Home Vote Mean", pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat (\cmidrule(lr){@span})) ///
style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) nomtitles collabels(none) title("Peer Vote Effects IV First Stage - Peer Vote Measures") replace


*** Peer Vote Effects by Issue Area 

foreach i of numlist 1(1)10 12 {

tab issueArea if issueArea == `i'

** Other Vote Mean IV - Ideology
* All active justices
qui ivregress 2sls vote_direction (other_vote_mean = justice_active_mean_1b) i.justice i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term if issueArea == `i', noconstant vce(cluster caseId) first
est store vote_mean_active_iv_`i'
estat firststage
mat fsFStat = r(singleresults)
estadd scalar fs = fsFStat[1,4] 

}

est table vote_mean_active_iv_*, ///
	stats(N r2 fs) keep(other_vote_mean) b(%9.4f) t(%9.3f) varlabel
		

** Process for outputting flexible table (rotated)
esttab vote_mean_active_iv_*, keep(other_vote_mean) se stats(fs N) replace	

preserve

matrix C = r(coefs)
matrix list C
matrix S = r(stats)
matrix list S

eststo clear

local rnames : rownames C

local issueArea_categories `" "Criminal\_Procedure" "Civil\_Rights" "First\_Amendment" "Due\_Process" "Privacy" "Attorneys" "Unions" "Economic\_Activity" "Judicial\_Power" "Federalism" "Federal\_Taxation" "'
local models : list uniq issueArea_categories

local i 0

foreach name of local rnames {
     local ++i
     local j 0
     capture matrix drop b
     capture matrix drop se
     foreach model of local models {
         local ++j
         matrix tmp = C[`i', 3*`j'-2]
         if tmp[1,1]<. {
             matrix colnames tmp = `model'
			 matrix b = nullmat(b), tmp
			 matrix tmp[1,1] = C[`i', 3*`j'-1]
             matrix se = nullmat(se), tmp
         }
     }
	 matrix list b
	 matrix list se
     
	 ereturn post b
     eststo `name'_b
	 estadd matrix se
	 ereturn post se
	 eststo `name'_se
 }

local snames : rownames S

local i 0

foreach name of local snames {
     local ++i
     local j 0
     capture matrix drop b
     foreach model of local models {
         local ++j
         matrix tmp = S[`i', `j']
         matrix colnames tmp = `model'
         matrix b = nullmat(b), tmp
		 matrix list b
     }
     ereturn post b
     eststo `name'
}
 
esttab, not mtitle noobs compress nonumb

esttab using Tables/table10.tex, cells(b(star fmt(%9.3f))) ///
	noomitted nobaselevels legend label noobs nonumb ///f
	style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels("Coefficient" "Standard Error" "First Stage F-Statistic" "Observations") collabels(none) title("Peer Effects by Issue Area - Justice by Issue Area, Term by Issue Area FE") replace	

eststo clear

restore	


******************** PEER EFFECT ON DECISIONS WITHIN CASE **********************

*** 8b. Peer Effects on Ideological Direction of Court Decision Using Circuit Court Relationships as Instrument for Votes

* Number of conservative votes in case
bysort casevote (voteId): egen number_conservative_case = total(vote_direction) if active == 1
* Number of conservative votes by others in case (to get measure excluding home justice)
bysort casevote (voteId): gen other_conservative_case = number_conservative_case - vote_direction if active == 1 
label variable other_conservative_case "Peer Conservative Votes"

* Ideology Potential for Case
// Need to analyse 'conservative potential' and 'liberal potential' separately 
// because by focusing on votes of others, middle values can give potential for either outcome. 
// 4-8 is a success for conservative potential, but 0-4 is a success for liberal potential, so 4 can be success for either. 

gen pot_conservative_case = (other_conservative_case >= ((number_active - 1)/2)) if !missing(other_conservative_case) & mod(number_active,2) == 1 // Potential to cause conservative outcome for directional cases
// Only defined for cases with odd number of justices to avoid mechanical relationship with lower court direction (since retained if tie) 

gen pot_liberal_case = (other_conservative_case <= ((number_active -1)/2)) if !missing(other_conservative_case) & mod(number_active,2) == 1 // Potential to cause liberal outcome for directional cases
label variable pot_liberal_case "Liberal Potential"
// Only defined for cases with odd number of justices to avoid mechanical relationship with lower court direction (since retained if tie) 


** Sample
// Want to just capture effect on away justices, so limit sample to:
// Cases with no home justices, all justices active - Group 2, keep all justices with weight 1/9
// Cases with single home justice, all justices active - Group 1, keep home justice and use their home status as the X variable of interest, give full weight

gen sample = (homeCircuitCourt_active_ave == 0 & homeCircuitCourt == 1 & number_active == 9) * 1 + ///
	(homeCircuitCourt_active_ave == 0 & homeCircuitCourt == 0 & number_active == 9) * 2

gen weight = 1 / number_active if sample == 2 // Cases with no home justice, equal weight to all
replace weight = 1 if sample == 1 & homeCircuitCourt == 1 // Cases with home justice, full weight to home justice obs


** IV Results - Effect of Home Justice Vote on Verdict Direction, with Justice Circuit Court History as Instrument

** Sample Restricted to Full Panel Cases with No Home Justice (Equal 1/9 Weight) or Single Home Justice (Full Weight)
* Effect of Own Vote Direction on Number of Other Conservative Votes, Full Panel Cases
qui ivregress 2sls other_conservative_case (vote_direction = i.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection) i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection i.term if sample != 0 [w = weight], noconstant vce(cluster caseId) first
est store number_other_cons_full
estat firststage
mat fsFStat = r(singleresults)
estadd scalar fs = fsFStat[1,4]
* Effect of Own Vote Direction on Conservative Potential, Full Panel Cases
qui ivregress 2sls pot_conservative_case (vote_direction = i.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection) i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection i.term if sample != 0 [w = weight], noconstant vce(cluster caseId) first
est store pot_cons_full
estat firststage
mat fsFStat = r(singleresults)
estadd scalar fs = fsFStat[1,4]
* Effect of Own Vote on Liberal Potential, Full Panel Cases
qui ivregress 2sls pot_liberal_case (vote_direction = i.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection) i.justice i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection i.term if sample != 0 [w = weight], noconstant vce(cluster caseId) first
est store pot_liberal_full
estat firststage
mat fsFStat = r(singleresults)
estadd scalar fs = fsFStat[1,4]

est table number_other_cons_full pot_cons_full pot_liberal_full, ///
	stats(N fs) keep(vote_direction) b(%9.4f) t(%9.3f) varlabel

esttab number_other_cons_full pot_cons_full pot_liberal_full using Tables/table9.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
noomitted nobaselevels keep(vote_direction) stats(N fs, fmt(%9.0g %9.3f) labels(Observations "First Stage F-Statistic")) legend label ///
style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Vote Effects on Verdict Direction Outcomes IV") replace


log close _all
exit, clear
