****************************** SETTINGS AND DATA *******************************

version 16.1

clear all
log close _all
set more off
set emptycells drop
set varabbrev off

local directory = ""
local folder = "`directory'" + "Replication/Data"
cd "`folder'"

* Robustness Tests Data
use robustnessData.dta

log using ../Output/Online_Appendix.log, replace name("Online Appendix")

* Set  Working Directory for Output
cd "../Output/Online Appendix"

****************************** ROBUSTNESS TESTS ********************************

* Set default omitted dummy variable to none, since estimating without constant
fvset base none justice caseSource
fvset base first issueArea term naturalCourt
fvset base 3 lcDispositionDirection 


*** 1. Median Peer Ideology

** 1a. Model 1 - Justice fixed effects, term fixed effects, clustered by case - Median Peer Ideology

local specificationlist `" "all" "joint" "active" "'

foreach spec in `specificationlist' {

capture drop justice_all_mean_1a justice_active_mean_1a justice_absent_mean_1a justice_FE_1a_prior justice_active_median_1a
capture drop absent_justice_case_j

* Initialise Peer Variables 
// Constant will be dropped
gen justice_all_mean_1a = 0
gen justice_active_mean_1a = 0
gen justice_absent_mean_1a = 0
gen justice_active_median_1a = 0
gen justice_FE_1a_prior = .

gen absent_justice_case_j = 0

local step_size = .

while `step_size' > 0.1^6 {

** Estimate regression - Judge fixed effects, dummies for term, clustered by case

* Peer effects, all other justices
if "`spec'" == "all" {
qui reg vote_direction i.justice justice_all_mean_1a justice_active_median_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
est store a_all
}
* Peer effects, active justices only
if "`spec'" == "active" {
qui reg vote_direction i.justice justice_active_mean_1a justice_active_median_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
est store a_active
}
* Peer effects, active and absent justices
if "`spec'" == "joint" {
qui reg vote_direction i.justice justice_active_mean_1a justice_absent_mean_1a absent_justice_case_j justice_active_median_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
est store a_joint
}

est table a_`spec', stats(r2 N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel

estimates restore a_`spec'
	
matrix all_ols_coef = e(b)
matrix justice_ols_coef_1a = all_ols_coef[1,1..36]' // 36 justices by issue area pairs in sample
matrix colnames justice_ols_coef_1a = justice_FE_1a
* matrix list justice_ols_coef_1a

drop justice_all_mean_1a justice_active_mean_1a justice_absent_mean_1a justice_active_mean_1a justice_active_median_1a


** Extract Justice Fixed Effects - a
// Using justice fixed effects, term dummies

** Matching justice with coefficient
* Note that matrices are not cleared with preserve / restore
preserve
bysort justice (dateDecision): keep if _n == 1 // Justices already ordered, earliest obs for each justice
mkmat justice, matrix(justice_list)
restore

matrix justice_ols_coef_merge_1a = (justice_list,justice_ols_coef_1a)
* matrix list justice_ols_coef_merge_1a

matsave justice_ols_coef_merge_1a, replace saving path("Estimates/")

** Merge coefficient as variable into dataset
merge m:1 justice using Estimates/justice_ols_coef_merge_1a.dta, keepusing(justice_FE_1a) keep(master match) nogenerate
label variable justice_FE_1a "Model 1 Ideology Estimates" 

sort voteId

* Normalise Justice FE to Baseline Mean (i.e. without Peer Effects)
// Note that adding/subtracting a constant is fully accounted for by the justice
// FE in following estimation, no effect on peer effects estimate

qui summarize justice_FE_1a_prior
local mean_prior = r(mean)
qui summarize justice_FE_1a
local mean_new = r(mean)

replace justice_FE_1a = justice_FE_1a - (`mean_new' - `mean_prior') if !missing(justice_FE_1a_prior)


** Peer Variable Creation - a

* Mean of coefficient for all other justices
bysort casevote ever_ideology_justice (voteId): egen justice_all_sum = total(justice_FE_1a)
bysort casevote ever_ideology_justice (voteId): gen justice_all_mean_1a = (justice_all_sum - justice_FE_1a) / (_N - 1)
drop justice_all_sum

* Mean of coefficients for other active justices
bysort casevote active (voteId): egen justice_active_sum = total(justice_FE_1a)
bysort casevote active (voteId): gen justice_active_mean_1a = (justice_active_sum - justice_FE_1a) / (_N - 1)
drop justice_active_sum

* Mean of coefficients for absent justices
bysort ever_ideology_justice: egen ideology_defined_mean_a = mean(justice_FE_1a)
bysort casevote ever_ideology_justice (voteId): egen justice_absent_sum = total(justice_FE_1a * (1-active))
// Mean of absent justices (don't need leave out mean, since absent justices omitted anyway)
gen justice_absent_mean_1a = justice_absent_sum / number_absent_ideology_j - ideology_defined_mean_a
// Subtracting mean defined ideology to provide natural zero for absent ideology
replace justice_absent_mean_1a = 0 if number_absent_ideology_j == 0 // No absent judges with defined ideology
drop justice_absent_sum ideology_defined_mean_a

* Median of Active Justices (Including Self)
bysort casevote active (voteId): egen justice_active_median_1a = median(justice_FE_1a)

label variable justice_all_mean_1a "Mean All Peer Justices"
label variable justice_active_mean_1a "Mean Active Peer Justices"
label variable justice_absent_mean_1a "Mean Absent Peer Justices"

label variable justice_active_median_1a "Median Active Justice"


** Measure of change in justice ideology measure
gen justice_FE_change = justice_FE_1a - justice_FE_1a_prior
summarize justice_FE_change
local step_size = r(sd)
disp `step_size'
drop justice_FE_change

replace justice_FE_1a_prior = justice_FE_1a
replace absent_justice_case_j = absent_justice_case_j_temp // Initialise for iterations with peer variable

drop justice_FE_1a

}

}

est table a_all a_active a_joint, ///
	stats(r2 N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel

esttab a_all a_active a_joint using Tables/MedianPeer.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
	noomitted nobaselevels keep(justice_all_mean_1a justice_active_mean_1a justice_absent_mean_1a justice_active_median_1a) stats(r2 N, fmt(%9.4f %9.0g) labels(R-squared Observations)) legend label ///
	style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Ideology Results - Justice Vote Direction (Conservative $\%$)") replace	
	
	
*** 2. Post Warren Court
	
** 1a. Model 1 - Justice fixed effects, term fixed effects, clustered by case - Post Warren Court

frames copy default postwarren, replace
cwf postwarren

tab naturalCourt
keep if naturalCourt >= 1501
tab naturalCourt

local specificationlist `" "all" "joint" "active" "'

foreach spec in `specificationlist' {

capture drop justice_all_mean_1a justice_active_mean_1a justice_absent_mean_1a justice_FE_1a_prior
capture drop absent_justice_case_j

* Initialise Peer Variables 
// Constant will be dropped
gen justice_all_mean_1a = 0
gen justice_active_mean_1a = 0
gen justice_absent_mean_1a = 0
gen justice_FE_1a_prior = .

gen absent_justice_case_j = 0

local step_size = .

while `step_size' > 0.1^6 {

** Estimate regression - Judge fixed effects, dummies for term, clustered by case

* Peer effects, all other justices
if "`spec'" == "all" {
qui reg vote_direction i.justice justice_all_mean_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
est store a_all
}
* Peer effects, active justices only
if "`spec'" == "active" {
qui reg vote_direction i.justice justice_active_mean_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
est store a_active
}
* Peer effects, active and absent justices
if "`spec'" == "joint" {
qui reg vote_direction i.justice justice_active_mean_1a justice_absent_mean_1a absent_justice_case_j i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
est store a_joint
}

est table a_`spec', stats(r2 N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel

estimates restore a_`spec'
	
matrix all_ols_coef = e(b)
matrix justice_ols_coef_1a = all_ols_coef[1,1..23]' // 36 justices by issue area pairs in sample
matrix colnames justice_ols_coef_1a = justice_FE_1a
* matrix list justice_ols_coef_1a

drop justice_all_mean_1a justice_active_mean_1a justice_absent_mean_1a justice_active_mean_1a


** Extract Justice Fixed Effects - a
// Using justice fixed effects, term dummies

** Matching justice with coefficient
* Note that matrices are not cleared with preserve / restore
preserve
bysort justice (dateDecision): keep if _n == 1 // Justices already ordered, earliest obs for each justice
mkmat justice, matrix(justice_list)
restore

matrix justice_ols_coef_merge_1a = (justice_list,justice_ols_coef_1a)
* matrix list justice_ols_coef_merge_1a

matsave justice_ols_coef_merge_1a, replace saving path("Estimates/")

** Merge coefficient as variable into dataset
merge m:1 justice using Estimates/justice_ols_coef_merge_1a.dta, keepusing(justice_FE_1a) keep(master match) nogenerate
label variable justice_FE_1a "Model 1 Ideology Estimates" 

sort voteId

* Normalise Justice FE to Baseline Mean (i.e. without Peer Effects)
// Note that adding/subtracting a constant is fully accounted for by the justice
// FE in following estimation, no effect on peer effects estimate

qui summarize justice_FE_1a_prior
local mean_prior = r(mean)
qui summarize justice_FE_1a
local mean_new = r(mean)

replace justice_FE_1a = justice_FE_1a - (`mean_new' - `mean_prior') if !missing(justice_FE_1a_prior)


** Peer Variable Creation - a

* Mean of coefficient for all other justices
bysort casevote ever_ideology_justice (voteId): egen justice_all_sum = total(justice_FE_1a)
bysort casevote ever_ideology_justice (voteId): gen justice_all_mean_1a = (justice_all_sum - justice_FE_1a) / (_N - 1)
drop justice_all_sum

* Mean of coefficients for other active justices
bysort casevote active (voteId): egen justice_active_sum = total(justice_FE_1a)
bysort casevote active (voteId): gen justice_active_mean_1a = (justice_active_sum - justice_FE_1a) / (_N - 1)
drop justice_active_sum

* Mean of coefficients for absent justices
bysort ever_ideology_justice: egen ideology_defined_mean_a = mean(justice_FE_1a)
bysort casevote ever_ideology_justice (voteId): egen justice_absent_sum = total(justice_FE_1a * (1-active))
// Mean of absent justices (don't need leave out mean, since absent justices omitted anyway)
gen justice_absent_mean_1a = justice_absent_sum / number_absent_ideology_j - ideology_defined_mean_a
// Subtracting mean defined ideology to provide natural zero for absent ideology
replace justice_absent_mean_1a = 0 if number_absent_ideology_j == 0 // No absent judges with defined ideology
drop justice_absent_sum ideology_defined_mean_a

label variable justice_all_mean_1a "Mean All Peer Justices"
label variable justice_active_mean_1a "Mean Active Peer Justices"
label variable justice_absent_mean_1a "Mean Absent Peer Justices"


** Measure of change in justice ideology measure
gen justice_FE_change = justice_FE_1a - justice_FE_1a_prior
summarize justice_FE_change
local step_size = r(sd)
disp `step_size'
drop justice_FE_change

replace justice_FE_1a_prior = justice_FE_1a
replace absent_justice_case_j = absent_justice_case_j_temp // Initialise for iterations with peer variable

drop justice_FE_1a

}

}

cwf default

est table a_all a_active a_joint, ///
	stats(r2 N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel	

esttab a_all a_active a_joint using Tables/PostWarren.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
	noomitted nobaselevels keep(justice_all_mean_1a justice_active_mean_1a justice_absent_mean_1a) stats(r2 N, fmt(%9.4f %9.0g) labels(R-squared Observations)) legend label ///
	style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Ideology Results - Justice Vote Direction (Conservative $\%$)") replace	
	
	
*** 3. Terms with No Change in Personnel

** 1a. Model 1 - Justice fixed effects, term fixed effects, clustered by case - Terms with Single Natural Court Only

bysort term: gen singleNaturalCourt = (naturalCourt[1] == naturalCourt[_N])
tab singleNaturalCourt
keep if singleNaturalCourt == 1

local specificationlist `" "all" "joint" "active" "'

foreach spec in `specificationlist' {

capture drop justice_all_mean_1a justice_active_mean_1a justice_absent_mean_1a justice_FE_1a_prior
capture drop absent_justice_case_j

* Initialise Peer Variables 
// Constant will be dropped
gen justice_all_mean_1a = 0
gen justice_active_mean_1a = 0
gen justice_absent_mean_1a = 0
gen justice_FE_1a_prior = .

gen absent_justice_case_j = 0

local step_size = .

while `step_size' > 0.1^6 {

** Estimate regression - Judge fixed effects, dummies for term, clustered by case

* Peer effects, all other justices
if "`spec'" == "all" {
qui reg vote_direction i.justice justice_all_mean_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
est store a_all
}
* Peer effects, active justices only
if "`spec'" == "active" {
qui reg vote_direction i.justice justice_active_mean_1a i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
est store a_active
}
* Peer effects, active and absent justices
if "`spec'" == "joint" {
qui reg vote_direction i.justice justice_active_mean_1a justice_absent_mean_1a absent_justice_case_j i.issueArea i(8 21(1)32).caseSource i.lcDispositionDirection c.homeCircuitCourt#i.lcDispositionDirection c.homeCircuitCourtYears#i.lcDispositionDirection i.term, noconstant vce(cluster caseId)
est store a_joint
}

est table a_`spec', stats(r2 N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel

estimates restore a_`spec'
	
matrix all_ols_coef = e(b)
matrix justice_ols_coef_1a = all_ols_coef[1,1..36]' // 36 justices by issue area pairs in sample
matrix colnames justice_ols_coef_1a = justice_FE_1a
* matrix list justice_ols_coef_1a

drop justice_all_mean_1a justice_active_mean_1a justice_absent_mean_1a justice_active_mean_1a


** Extract Justice Fixed Effects - a
// Using justice fixed effects, term dummies

** Matching justice with coefficient
* Note that matrices are not cleared with preserve / restore
preserve
bysort justice (dateDecision): keep if _n == 1 // Justices already ordered, earliest obs for each justice
mkmat justice, matrix(justice_list)
restore

matrix justice_ols_coef_merge_1a = (justice_list,justice_ols_coef_1a)
* matrix list justice_ols_coef_merge_1a

matsave justice_ols_coef_merge_1a, replace saving path("Estimates/")

** Merge coefficient as variable into dataset
merge m:1 justice using Estimates/justice_ols_coef_merge_1a.dta, keepusing(justice_FE_1a) keep(master match) nogenerate
label variable justice_FE_1a "Model 1 Ideology Estimates" 

sort voteId

* Normalise Justice FE to Baseline Mean (i.e. without Peer Effects)
// Note that adding/subtracting a constant is fully accounted for by the justice
// FE in following estimation, no effect on peer effects estimate

qui summarize justice_FE_1a_prior
local mean_prior = r(mean)
qui summarize justice_FE_1a
local mean_new = r(mean)

replace justice_FE_1a = justice_FE_1a - (`mean_new' - `mean_prior') if !missing(justice_FE_1a_prior)


** Peer Variable Creation - a

* Mean of coefficient for all other justices
bysort casevote ever_ideology_justice (voteId): egen justice_all_sum = total(justice_FE_1a)
bysort casevote ever_ideology_justice (voteId): gen justice_all_mean_1a = (justice_all_sum - justice_FE_1a) / (_N - 1)
drop justice_all_sum

* Mean of coefficients for other active justices
bysort casevote active (voteId): egen justice_active_sum = total(justice_FE_1a)
bysort casevote active (voteId): gen justice_active_mean_1a = (justice_active_sum - justice_FE_1a) / (_N - 1)
drop justice_active_sum

* Mean of coefficients for absent justices
bysort ever_ideology_justice: egen ideology_defined_mean_a = mean(justice_FE_1a)
bysort casevote ever_ideology_justice (voteId): egen justice_absent_sum = total(justice_FE_1a * (1-active))
// Mean of absent justices (don't need leave out mean, since absent justices omitted anyway)
gen justice_absent_mean_1a = justice_absent_sum / number_absent_ideology_j - ideology_defined_mean_a
// Subtracting mean defined ideology to provide natural zero for absent ideology
replace justice_absent_mean_1a = 0 if number_absent_ideology_j == 0 // No absent judges with defined ideology
drop justice_absent_sum ideology_defined_mean_a

label variable justice_all_mean_1a "Mean All Peer Justices"
label variable justice_active_mean_1a "Mean Active Peer Justices"
label variable justice_absent_mean_1a "Mean Absent Peer Justices"


** Measure of change in justice ideology measure
gen justice_FE_change = justice_FE_1a - justice_FE_1a_prior
summarize justice_FE_change
local step_size = r(sd)
disp `step_size'
drop justice_FE_change

replace justice_FE_1a_prior = justice_FE_1a
replace absent_justice_case_j = absent_justice_case_j_temp // Initialise for iterations with peer variable

drop justice_FE_1a

}

}

est table a_all a_active a_joint, ///
	stats(r2 N) keep(justice_*) b(%9.4f) t(%9.3f) varlabel

esttab a_all a_active a_joint using Tables/fixedPersonnel.tex, cells(b(star fmt(%9.3f)) se(par fmt(%9.3f))) ///
	noomitted nobaselevels keep(justice_all_mean_1a justice_active_mean_1a justice_absent_mean_1a) stats(r2 N, fmt(%9.4f %9.0g) labels(R-squared Observations)) legend label ///
	style(tex) starlevels(* 0.10 ** 0.05 *** 0.01) mlabels(, depvars) collabels(none) title("Peer Ideology Results - Justice Vote Direction (Conservative $\%$)") replace


log close _all
exit, clear	
	